@@ -17,7 +17,16 @@
 
 package org.apache.seatunnel.api.sink;
 
+import org.apache.seatunnel.api.annotation.Experimental;
+import org.apache.seatunnel.api.configuration.Option;
+import org.apache.seatunnel.api.configuration.Options;
+
 public class SinkCommonOptions {
 
-    public static final String DATA_SAVE_MODE = "save_mode";
+    @Experimental
+    public static Option<Integer> MULTI_TABLE_SINK_REPLICA =
+            Options.key("multi_table_sink_replica")
+                    .intType()
+                    .defaultValue(1)
+                    .withDescription("The replica number of multi table sink");
 }
