@@ -20,6 +20,7 @@ package org.apache.seatunnel.connectors.doris.source.serialization;
 import org.apache.seatunnel.shade.org.apache.arrow.memory.RootAllocator;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.BigIntVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.BitVector;
+import org.apache.seatunnel.shade.org.apache.arrow.vector.DateDayVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.DecimalVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.FieldVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.FixedSizeBinaryVector;
@@ -27,6 +28,7 @@ import org.apache.seatunnel.shade.org.apache.arrow.vector.Float4Vector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.Float8Vector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.IntVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.SmallIntVector;
+import org.apache.seatunnel.shade.org.apache.arrow.vector.TimeStampMicroVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.TinyIntVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.VarCharVector;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.VectorSchemaRoot;
@@ -39,9 +41,15 @@ import org.apache.seatunnel.shade.org.apache.arrow.vector.types.Types;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.types.Types.MinorType;
 import org.apache.seatunnel.shade.org.apache.arrow.vector.util.Text;
 
+import org.apache.seatunnel.api.table.type.ArrayType;
+import org.apache.seatunnel.api.table.type.DecimalArrayType;
+import org.apache.seatunnel.api.table.type.MapType;
 import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
+import org.apache.seatunnel.api.table.type.SqlType;
+import org.apache.seatunnel.common.utils.DateTimeUtils;
+import org.apache.seatunnel.common.utils.DateUtils;
 import org.apache.seatunnel.connectors.doris.exception.DorisConnectorErrorCode;
 import org.apache.seatunnel.connectors.doris.exception.DorisConnectorException;
 
@@ -67,21 +75,21 @@ import java.util.function.IntFunction;
 
 @Slf4j
 public class RowBatch {
-    // offset for iterate the rowBatch
-    private int offsetInRowBatch = 0;
-    private int rowCountInOneBatch = 0;
-    private int readRowCount = 0;
     SeaTunnelDataType<?>[] fieldTypes;
-    private List<SeaTunnelRow> seatunnelRowBatch = new ArrayList<>();
     private final ArrowStreamReader arrowStreamReader;
-    private VectorSchemaRoot root;
-    private List<FieldVector> fieldVectors;
-    private RootAllocator rootAllocator;
     private final String DATETIME_PATTERN = "yyyy-MM-dd HH:mm:ss";
     private final String DATETIMEV2_PATTERN = "yyyy-MM-dd HH:mm:ss.SSSSSS";
     private final DateTimeFormatter dateTimeV2Formatter =
             DateTimeFormatter.ofPattern(DATETIMEV2_PATTERN);
     private final DateTimeFormatter dateFormatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
+    // offset for iterate the rowBatch
+    private int offsetInRowBatch = 0;
+    private int rowCountInOneBatch = 0;
+    private int readRowCount = 0;
+    private List<SeaTunnelRow> seatunnelRowBatch = new ArrayList<>();
+    private VectorSchemaRoot root;
+    private List<FieldVector> fieldVectors;
+    private RootAllocator rootAllocator;
 
     public RowBatch(TScanBatchResult nextResult, SeaTunnelRowType seaTunnelRowType) {
         this.rootAllocator = new RootAllocator(Integer.MAX_VALUE);
@@ -126,7 +134,7 @@ public class RowBatch {
                 readRowCount += root.getRowCount();
             }
             return this;
-        } catch (Exception e) {
+        } catch (Throwable e) {
             log.error("Read Doris Data failed because: ", e);
             throw new DorisConnectorException(
                     DorisConnectorErrorCode.ARROW_READ_FAILED, e.getMessage());
@@ -157,16 +165,20 @@ public class RowBatch {
 
                 FieldVector fieldVector = fieldVectors.get(col);
                 Types.MinorType minorType = fieldVector.getMinorType();
-                convertArrowValue(col, currentType, minorType, fieldVector);
+                convertArrowValue(col, currentType, dataType, minorType, fieldVector);
             }
-        } catch (Exception e) {
+        } catch (Throwable e) {
             close();
             throw e;
         }
     }
 
     private void convertArrowValue(
-            int col, String currentType, Types.MinorType minorType, FieldVector fieldVector) {
+            int col,
+            String currentType,
+            SeaTunnelDataType<?> dataType,
+            MinorType minorType,
+            FieldVector fieldVector) {
         switch (currentType) {
             case "BOOLEAN":
                 BitVector bitVector = (BitVector) fieldVector;
@@ -260,6 +272,45 @@ public class RowBatch {
                                 float8Vector.isNull(rowIndex) ? null : float8Vector.get(rowIndex));
                 break;
             case "DECIMAL":
+                // LARGEINT
+                if (fieldVector instanceof FixedSizeBinaryVector) {
+                    FixedSizeBinaryVector largeInitFixedSizeBinaryVector =
+                            (FixedSizeBinaryVector) fieldVector;
+                    Preconditions.checkArgument(
+                            minorType.equals(Types.MinorType.FIXEDSIZEBINARY),
+                            typeMismatchMessage(currentType, minorType));
+                    addValueToRowForAllRows(
+                            col,
+                            rowIndex -> {
+                                if (largeInitFixedSizeBinaryVector.isNull(rowIndex)) {
+                                    return null;
+                                }
+                                byte[] bytes = largeInitFixedSizeBinaryVector.get(rowIndex);
+                                int left = 0, right = bytes.length - 1;
+                                while (left < right) {
+                                    byte temp = bytes[left];
+                                    bytes[left] = bytes[right];
+                                    bytes[right] = temp;
+                                    left++;
+                                    right--;
+                                }
+                                return new BigDecimal(new BigInteger(bytes), 0);
+                            });
+                    break;
+                } else if (fieldVector instanceof VarCharVector) {
+                    VarCharVector varCharVector = (VarCharVector) fieldVector;
+                    Preconditions.checkArgument(
+                            minorType.equals(Types.MinorType.VARCHAR),
+                            typeMismatchMessage(currentType, minorType));
+                    addValueToRowForAllRows(
+                            col,
+                            rowIndex ->
+                                    varCharVector.isNull(rowIndex)
+                                            ? null
+                                            : new BigDecimal(
+                                                    new String(varCharVector.get(rowIndex))));
+                    break;
+                }
                 DecimalVector decimalVector = (DecimalVector) fieldVector;
                 Preconditions.checkArgument(
                         minorType.equals(Types.MinorType.DECIMAL),
@@ -273,6 +324,21 @@ public class RowBatch {
                 break;
             case "DATE":
             case "DATEV2":
+                if (fieldVector instanceof DateDayVector) {
+                    DateDayVector dateVector = (DateDayVector) fieldVector;
+                    Preconditions.checkArgument(
+                            minorType.equals(Types.MinorType.DATEDAY),
+                            typeMismatchMessage(currentType, minorType));
+                    addValueToRowForAllRows(
+                            col,
+                            rowIndex -> {
+                                if (dateVector.isNull(rowIndex)) {
+                                    return null;
+                                }
+                                return LocalDate.ofEpochDay(dateVector.get(rowIndex));
+                            });
+                    break;
+                }
                 VarCharVector dateVector = (VarCharVector) fieldVector;
                 Preconditions.checkArgument(
                         minorType.equals(Types.MinorType.VARCHAR),
@@ -288,6 +354,22 @@ public class RowBatch {
                         });
                 break;
             case "TIMESTAMP":
+                if (fieldVector instanceof TimeStampMicroVector) {
+                    TimeStampMicroVector timestampVector = (TimeStampMicroVector) fieldVector;
+
+                    addValueToRowForAllRows(
+                            col,
+                            rowIndex -> {
+                                if (timestampVector.isNull(rowIndex)) {
+                                    return null;
+                                }
+                                String stringValue = timestampVector.getObject(rowIndex).toString();
+                                stringValue = completeMilliseconds(stringValue);
+
+                                return DateTimeUtils.parse(stringValue);
+                            });
+                    break;
+                }
                 VarCharVector timestampVector = (VarCharVector) fieldVector;
                 Preconditions.checkArgument(
                         minorType.equals(Types.MinorType.VARCHAR),
@@ -395,31 +477,7 @@ public class RowBatch {
                 Preconditions.checkArgument(
                         minorType.equals(Types.MinorType.LIST),
                         typeMismatchMessage(currentType, minorType));
-                addValueToRowForAllRows(
-                        col,
-                        rowIndex -> {
-                            if (listVector.isNull(rowIndex)) {
-                                return null;
-                            }
-                            List<?> listVectorObject = listVector.getObject(rowIndex);
-                            if (listVectorObject.get(0) instanceof BigDecimal
-                                    || listVectorObject.get(0) instanceof Text) {
-                                return listVectorObject.stream()
-                                        .map(Object::toString)
-                                        .toArray(String[]::new);
-                            }
-                            if (listVectorObject.get(0) instanceof Boolean) {
-                                return listVectorObject.stream()
-                                        .map(x -> (Boolean) x ? (short) 1 : (short) 0)
-                                        .toArray(Short[]::new);
-                            }
-                            if (listVectorObject.get(0) instanceof Byte) {
-                                return listVectorObject.stream()
-                                        .map(x -> ((Byte) x).shortValue())
-                                        .toArray(Short[]::new);
-                            }
-                            return listVectorObject.toArray();
-                        });
+                addValueToRowForArrayColumn(dataType, col, listVector);
                 break;
             case "MAP":
                 MapVector mapVector = (MapVector) fieldVector;
@@ -427,21 +485,7 @@ public class RowBatch {
                 Preconditions.checkArgument(
                         minorType.equals(MinorType.MAP),
                         typeMismatchMessage(currentType, minorType));
-                addValueToRowForAllRows(
-                        col,
-                        rowIndex -> {
-                            if (mapVector.isNull(rowIndex)) {
-                                return null;
-                            }
-                            reader.setPosition(rowIndex);
-                            Map<Object, Object> mapValue = new HashMap<>();
-                            while (reader.next()) {
-                                mapValue.put(
-                                        reader.key().readObject().toString(),
-                                        reader.value().readObject().toString());
-                            }
-                            return mapValue;
-                        });
+                addValueToRowForMapColumn(dataType, col, mapVector, reader);
 
                 break;
             case "STRUCT":
@@ -467,6 +511,179 @@ public class RowBatch {
         }
     }
 
+    private void addValueToRowForMapColumn(
+            SeaTunnelDataType<?> dataType, int col, MapVector mapVector, UnionMapReader reader) {
+        addValueToRowForAllRows(
+                col,
+                rowIndex -> {
+                    if (mapVector.isNull(rowIndex)) {
+                        return null;
+                    }
+                    reader.setPosition(rowIndex);
+                    Map<Object, Object> mapValue = new HashMap<>();
+                    MapType mapType = (MapType) dataType;
+                    SqlType keyType = mapType.getKeyType().getSqlType();
+                    SqlType valueType = mapType.getValueType().getSqlType();
+                    while (reader.next()) {
+                        mapValue.put(
+                                getDataFromVector(reader.key().readObject(), keyType),
+                                getDataFromVector(reader.value().readObject(), valueType));
+                    }
+                    return mapValue;
+                });
+    }
+
+    private Object getDataFromVector(Object vectorObject, SqlType sqlType) {
+        if (vectorObject instanceof Boolean) {
+            return Boolean.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Byte) {
+            return Byte.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Short) {
+            return Short.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Integer) {
+            if (sqlType.equals(SqlType.DATE)) {
+                return LocalDate.ofEpochDay((int) vectorObject);
+            }
+            return Integer.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Long) {
+            return Long.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Float) {
+            return Float.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Double) {
+            return Double.valueOf(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof Text) {
+            if (sqlType.equals(SqlType.TIMESTAMP)) {
+                String stringValue = completeMilliseconds(vectorObject.toString());
+                return LocalDateTime.parse(stringValue, dateTimeV2Formatter);
+            } else if (sqlType.equals(SqlType.DATE)) {
+                return LocalDate.parse(vectorObject.toString(), dateFormatter);
+            } else if (sqlType.equals(SqlType.DECIMAL)) {
+                return new BigDecimal(vectorObject.toString());
+            }
+            return vectorObject.toString();
+        }
+
+        if (vectorObject instanceof BigDecimal) {
+            return new BigDecimal(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof byte[] && sqlType.equals(SqlType.DECIMAL)) {
+            byte[] bytes = (byte[]) vectorObject;
+            int left = 0, right = bytes.length - 1;
+            while (left < right) {
+                byte temp = bytes[left];
+                bytes[left] = bytes[right];
+                bytes[right] = temp;
+                left++;
+                right--;
+            }
+            return new BigDecimal(new BigInteger(bytes), 0);
+        }
+        if (vectorObject instanceof LocalDate) {
+            return DateUtils.parse(vectorObject.toString());
+        }
+
+        if (vectorObject instanceof LocalDateTime) {
+            return DateTimeUtils.parse(vectorObject.toString());
+        }
+
+        return vectorObject.toString();
+    }
+
+    private void addValueToRowForArrayColumn(
+            SeaTunnelDataType<?> dataType, int col, ListVector listVector) {
+        SqlType eleSqlType = null;
+        if (dataType instanceof ArrayType) {
+            ArrayType arrayType = (ArrayType) dataType;
+            eleSqlType = arrayType.getElementType().getSqlType();
+        }
+        SqlType finalEleSqlType = eleSqlType;
+        addValueToRowForAllRows(
+                col,
+                rowIndex -> {
+                    if (listVector.isNull(rowIndex)) {
+                        return null;
+                    }
+                    List<?> listVectorObject = listVector.getObject(rowIndex);
+                    if (listVectorObject.get(0) instanceof Boolean) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Boolean[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Byte) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Byte[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Short) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Short[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Integer) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Integer[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Long) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Long[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Float) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Float[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Double) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(Double[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof Text) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(String[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof BigDecimal) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(BigDecimal[]::new);
+                    }
+
+                    if (listVectorObject.get(0) instanceof byte[]
+                            && dataType instanceof DecimalArrayType) {
+                        return listVectorObject.stream()
+                                .map(x -> getDataFromVector(x, finalEleSqlType))
+                                .toArray(BigDecimal[]::new);
+                    }
+
+                    return listVectorObject.toArray();
+                });
+    }
+
     private void addValueToRowForAllRows(int col, IntFunction<Object> function) {
         for (int rowIndex = 0; rowIndex < rowCountInOneBatch; rowIndex++) {
             Object fieldValue = function.apply(rowIndex);
