@@ -18,12 +18,12 @@
 package org.apache.seatunnel.connectors.seatunnel.iceberg.source.enumerator;
 
 import org.apache.seatunnel.api.source.SourceSplitEnumerator;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.IcebergTableLoader;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.config.SourceConfig;
 import org.apache.seatunnel.connectors.seatunnel.iceberg.source.split.IcebergFileScanTaskSplit;
 
 import org.apache.iceberg.Table;
-import org.apache.iceberg.util.ThreadPools;
 
 import lombok.Getter;
 import lombok.NonNull;
@@ -48,19 +48,22 @@ public abstract class AbstractSplitEnumerator
 
     protected IcebergTableLoader icebergTableLoader;
     @Getter private volatile boolean isOpen = false;
+    private CatalogTable catalogTable;
 
     public AbstractSplitEnumerator(
             @NonNull SourceSplitEnumerator.Context<IcebergFileScanTaskSplit> context,
             @NonNull SourceConfig sourceConfig,
-            @NonNull Map<Integer, List<IcebergFileScanTaskSplit>> pendingSplits) {
+            @NonNull Map<Integer, List<IcebergFileScanTaskSplit>> pendingSplits,
+            CatalogTable catalogTable) {
         this.context = context;
         this.sourceConfig = sourceConfig;
         this.pendingSplits = new HashMap<>(pendingSplits);
+        this.catalogTable = catalogTable;
     }
 
     @Override
     public void open() {
-        icebergTableLoader = IcebergTableLoader.create(sourceConfig);
+        icebergTableLoader = IcebergTableLoader.create(sourceConfig, catalogTable);
         icebergTableLoader.open();
         isOpen = true;
     }
@@ -75,8 +78,6 @@ public abstract class AbstractSplitEnumerator
     public void close() throws IOException {
         icebergTableLoader.close();
         isOpen = false;
-        // TODO we should remove shutdown logic when supported closed part task
-        ThreadPools.getWorkerPool().shutdownNow();
     }
 
     @Override
