@@ -17,11 +17,20 @@
 
 package org.apache.seatunnel.connectors.seatunnel.influxdb.sink;
 
+import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.configuration.util.OptionRule;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.connector.TableSink;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactory;
+import org.apache.seatunnel.api.table.factory.TableSinkFactoryContext;
+import org.apache.seatunnel.connectors.seatunnel.influxdb.config.SinkConfig;
 
 import com.google.auto.service.AutoService;
+import lombok.extern.slf4j.Slf4j;
+
+import java.util.HashMap;
+import java.util.Map;
 
 import static org.apache.seatunnel.connectors.seatunnel.influxdb.config.InfluxDBConfig.CONNECT_TIMEOUT_MS;
 import static org.apache.seatunnel.connectors.seatunnel.influxdb.config.InfluxDBConfig.DATABASES;
@@ -36,6 +45,7 @@ import static org.apache.seatunnel.connectors.seatunnel.influxdb.config.SinkConf
 import static org.apache.seatunnel.connectors.seatunnel.influxdb.config.SinkConfig.RETRY_BACKOFF_MULTIPLIER_MS;
 
 @AutoService(Factory.class)
+@Slf4j
 public class InfluxDBSinkFactory implements TableSinkFactory {
 
     @Override
@@ -46,10 +56,11 @@ public class InfluxDBSinkFactory implements TableSinkFactory {
     @Override
     public OptionRule optionRule() {
         return OptionRule.builder()
-                .required(URL, DATABASES, KEY_MEASUREMENT)
+                .required(URL, DATABASES)
                 .bundled(USERNAME, PASSWORD)
                 .optional(
                         CONNECT_TIMEOUT_MS,
+                        KEY_MEASUREMENT,
                         KEY_TAGS,
                         KEY_TIME,
                         BATCH_SIZE,
@@ -57,4 +68,17 @@ public class InfluxDBSinkFactory implements TableSinkFactory {
                         RETRY_BACKOFF_MULTIPLIER_MS)
                 .build();
     }
+
+    @Override
+    public TableSink createSink(TableSinkFactoryContext context) {
+        ReadonlyConfig config = context.getOptions();
+        CatalogTable catalogTable = context.getCatalogTable();
+        if (!config.getOptional(KEY_MEASUREMENT).isPresent()) {
+            Map<String, String> map = config.toMap();
+            map.put(KEY_MEASUREMENT.key(), catalogTable.getTableId().toTablePath().getFullName());
+            config = ReadonlyConfig.fromMap(new HashMap<>(map));
+        }
+        SinkConfig sinkConfig = new SinkConfig(config.toConfig());
+        return () -> new InfluxDBSink(sinkConfig, catalogTable);
+    }
 }
