@@ -19,14 +19,14 @@ package org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql;
 
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.Column;
-import org.apache.seatunnel.api.table.catalog.PhysicalColumn;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.exception.CatalogException;
 import org.apache.seatunnel.api.table.catalog.exception.DatabaseNotExistException;
-import org.apache.seatunnel.api.table.type.SeaTunnelDataType;
+import org.apache.seatunnel.api.table.converter.BasicTypeDefine;
 import org.apache.seatunnel.common.utils.JdbcUrlUtil;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.AbstractJdbcCatalog;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.utils.CatalogUtils;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.psql.PostgresTypeConverter;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.psql.PostgresTypeMapper;
 
 import org.apache.commons.collections4.CollectionUtils;
@@ -37,43 +37,33 @@ import lombok.extern.slf4j.Slf4j;
 import java.sql.Connection;
 import java.sql.ResultSet;
 import java.sql.SQLException;
-import java.util.HashMap;
-import java.util.Map;
-
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_BIT;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_BYTEA;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_CHAR;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_CHARACTER;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_CHARACTER_VARYING;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_GEOGRAPHY;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_GEOMETRY;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_INTERVAL;
-import static org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.psql.PostgresDataTypeConvertor.PG_TEXT;
 
 @Slf4j
 public class PostgresCatalog extends AbstractJdbcCatalog {
 
-    private static final PostgresDataTypeConvertor DATA_TYPE_CONVERTOR =
-            new PostgresDataTypeConvertor();
-
     private static final String SELECT_COLUMNS_SQL_TEMPLATE =
             "SELECT \n"
                     + "    a.attname AS column_name, \n"
                     + "\t\tt.typname as type_name,\n"
                     + "    CASE \n"
+                    + "        WHEN a.atttypmod = -1 THEN t.typname\n"
                     + "        WHEN t.typname = 'varchar' THEN t.typname || '(' || (a.atttypmod - 4) || ')'\n"
                     + "        WHEN t.typname = 'bpchar' THEN 'char' || '(' || (a.atttypmod - 4) || ')'\n"
                     + "        WHEN t.typname = 'numeric' OR t.typname = 'decimal' THEN t.typname || '(' || ((a.atttypmod - 4) >> 16) || ', ' || ((a.atttypmod - 4) & 65535) || ')'\n"
                     + "        WHEN t.typname = 'bit' OR t.typname = 'bit varying' THEN t.typname || '(' || (a.atttypmod - 4) || ')'\n"
+                    + "        WHEN t.typname IN ('time', 'timetz', 'timestamp', 'timestamptz') THEN t.typname || '(' || a.atttypmod || ')'\n"
                     + "        ELSE t.typname || '' \n"
                     + "    END AS full_type_name,\n"
                     + "    CASE\n"
+                    + "        WHEN a.atttypmod = -1 THEN NULL\n"
                     + "        WHEN t.typname IN ('varchar', 'bpchar', 'bit', 'bit varying') THEN a.atttypmod - 4\n"
                     + "        WHEN t.typname IN ('numeric', 'decimal') THEN (a.atttypmod - 4) >> 16\n"
                     + "        ELSE NULL\n"
                     + "    END AS column_length,\n"
                     + "\t\tCASE\n"
+                    + "        WHEN a.atttypmod = -1 THEN NULL\n"
                     + "        WHEN t.typname IN ('numeric', 'decimal') THEN (a.atttypmod - 4) & 65535\n"
+                    + "        WHEN t.typname IN ('time', 'timetz', 'timestamp', 'timestamptz') THEN a.atttypmod\n"
                     + "        ELSE NULL\n"
                     + "    END AS column_scale,\n"
                     + "\t\td.description AS column_comment,\n"
@@ -136,54 +126,34 @@ public class PostgresCatalog extends AbstractJdbcCatalog {
         String typeName = resultSet.getString("type_name");
         String fullTypeName = resultSet.getString("full_type_name");
         long columnLength = resultSet.getLong("column_length");
-        long columnScale = resultSet.getLong("column_scale");
+        int columnScale = resultSet.getInt("column_scale");
         String columnComment = resultSet.getString("column_comment");
         Object defaultValue = resultSet.getObject("default_value");
         boolean isNullable = resultSet.getString("is_nullable").equals("YES");
 
+        // dealingSpecialNumeric
+        if (typeName.equals(PostgresTypeConverter.PG_NUMERIC) && columnLength < 1) {
+            fullTypeName = "numeric(38,10)";
+            columnLength = 38;
+            columnScale = 10;
+        }
         if (defaultValue != null && defaultValue.toString().contains("regclass")) {
             defaultValue = null;
         }
 
-        SeaTunnelDataType<?> type = fromJdbcType(columnName, typeName, columnLength, columnScale);
-        long bitLen = 0;
-        switch (typeName) {
-            case PG_BYTEA:
-                bitLen = -1;
-                break;
-            case PG_TEXT:
-                columnLength = -1;
-                break;
-            case PG_INTERVAL:
-                columnLength = 50;
-                break;
-            case PG_GEOMETRY:
-            case PG_GEOGRAPHY:
-                columnLength = 255;
-                break;
-            case PG_BIT:
-                bitLen = columnLength;
-                break;
-            case PG_CHAR:
-            case PG_CHARACTER:
-            case PG_CHARACTER_VARYING:
-            default:
-                break;
-        }
-
-        return PhysicalColumn.of(
-                columnName,
-                type,
-                0,
-                isNullable,
-                defaultValue,
-                columnComment,
-                fullTypeName,
-                false,
-                false,
-                bitLen,
-                null,
-                columnLength);
+        BasicTypeDefine typeDefine =
+                BasicTypeDefine.builder()
+                        .name(columnName)
+                        .columnType(fullTypeName)
+                        .dataType(typeName)
+                        .length(columnLength)
+                        .precision(columnLength)
+                        .scale(columnScale)
+                        .nullable(isNullable)
+                        .defaultValue(defaultValue)
+                        .comment(columnComment)
+                        .build();
+        return PostgresTypeConverter.INSTANCE.convert(typeDefine);
     }
 
     @Override
@@ -216,6 +186,13 @@ public class PostgresCatalog extends AbstractJdbcCatalog {
         }
     }
 
+    @Override
+    protected String getCreateTableSql(TablePath tablePath, CatalogTable table) {
+        PostgresCreateTableSqlBuilder postgresCreateTableSqlBuilder =
+                new PostgresCreateTableSqlBuilder(table);
+        return postgresCreateTableSqlBuilder.build(tablePath);
+    }
+
     @Override
     protected String getDropTableSql(TablePath tablePath) {
         return "DROP TABLE \""
@@ -254,14 +231,6 @@ public class PostgresCatalog extends AbstractJdbcCatalog {
         super.dropDatabaseInternal(databaseName);
     }
 
-    private SeaTunnelDataType<?> fromJdbcType(
-            String columnName, String typeName, long precision, long scale) {
-        Map<String, Object> dataTypeProperties = new HashMap<>();
-        dataTypeProperties.put(PostgresDataTypeConvertor.PRECISION, precision);
-        dataTypeProperties.put(PostgresDataTypeConvertor.SCALE, scale);
-        return DATA_TYPE_CONVERTOR.toSeaTunnelType(columnName, typeName, dataTypeProperties);
-    }
-
     @Override
     public boolean tableExists(TablePath tablePath) throws CatalogException {
         try {
