@@ -118,7 +118,7 @@ public class CatalogUtils {
         while (rs.next()) {
             String columnName = rs.getString("COLUMN_NAME");
             // all the PK_NAME should be the same
-            pkName = rs.getString("PK_NAME");
+            pkName = cleanKeyName(rs.getString("PK_NAME"));
             int keySeq = rs.getInt("KEY_SEQ");
             // KEY_SEQ is 1-based index
             primaryKeyColumns.add(Pair.of(keySeq, columnName));
@@ -128,6 +128,7 @@ public class CatalogUtils {
                 primaryKeyColumns.stream()
                         .sorted(Comparator.comparingInt(Pair::getKey))
                         .map(Pair::getValue)
+                        .distinct()
                         .collect(Collectors.toList());
         if (CollectionUtils.isEmpty(pkFields)) {
             return Optional.empty();
@@ -152,7 +153,7 @@ public class CatalogUtils {
             if (columnName == null) {
                 continue;
             }
-            String indexName = resultSet.getString("INDEX_NAME");
+            String indexName = cleanKeyName(resultSet.getString("INDEX_NAME"));
             boolean noUnique = resultSet.getBoolean("NON_UNIQUE");
 
             ConstraintKey constraintKey =
@@ -179,6 +180,15 @@ public class CatalogUtils {
         return new ArrayList<>(constraintKeyMap.values());
     }
 
+    private static String cleanKeyName(String keyName) {
+        if (keyName != null) {
+            // only keep the characters that are valid in an index name
+            keyName = keyName.replaceAll("[^a-zA-Z0-9_]", "");
+            keyName = keyName.replaceAll("^_+", "");
+        }
+        return keyName;
+    }
+
     public static TableSchema getTableSchema(
             DatabaseMetaData metadata, TablePath tablePath, JdbcDialectTypeMapper typeMapper)
             throws SQLException {
