@@ -18,10 +18,11 @@
 package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.redshift;
 
 import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.converter.AbstractJdbcRowConverter;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect.DatabaseIdentifier;
 
 public class RedshiftJdbcRowConverter extends AbstractJdbcRowConverter {
     @Override
     public String converterName() {
-        return "Redshift";
+        return DatabaseIdentifier.REDSHIFT;
     }
 }
