@@ -35,6 +35,8 @@ import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.TableSchema;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.iris.IrisCatalog;
+import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.iris.savemode.IrisSaveModeHandler;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.utils.CatalogUtils;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcOptions;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.config.JdbcSinkConfig;
@@ -98,12 +100,13 @@ public class JdbcSink
     }
 
     @Override
-    public SinkWriter<SeaTunnelRow, XidInfo, JdbcSinkState> createWriter(
-            SinkWriter.Context context) {
-        SinkWriter<SeaTunnelRow, XidInfo, JdbcSinkState> sinkWriter;
+    public AbstractJdbcSinkWriter createWriter(SinkWriter.Context context) {
+        TablePath sinkTablePath = catalogTable.getTablePath();
+        AbstractJdbcSinkWriter sinkWriter;
         if (jdbcSinkConfig.isExactlyOnce()) {
             sinkWriter =
                     new JdbcExactlyOnceSinkWriter(
+                            sinkTablePath,
                             context,
                             jobContext,
                             dialect,
@@ -115,10 +118,12 @@ public class JdbcSink
                 String keyName = tableSchema.getPrimaryKey().getColumnNames().get(0);
                 int index = tableSchema.toPhysicalRowDataType().indexOf(keyName);
                 if (index > -1) {
-                    return new JdbcSinkWriter(dialect, jdbcSinkConfig, tableSchema, index);
+                    return new JdbcSinkWriter(
+                            sinkTablePath, dialect, jdbcSinkConfig, tableSchema, index);
                 }
             }
-            sinkWriter = new JdbcSinkWriter(dialect, jdbcSinkConfig, tableSchema, null);
+            sinkWriter =
+                    new JdbcSinkWriter(sinkTablePath, dialect, jdbcSinkConfig, tableSchema, null);
         }
         return sinkWriter;
     }
@@ -126,9 +131,16 @@ public class JdbcSink
     @Override
     public SinkWriter<SeaTunnelRow, XidInfo, JdbcSinkState> restoreWriter(
             SinkWriter.Context context, List<JdbcSinkState> states) throws IOException {
+        TablePath sinkTablePath = catalogTable.getTablePath();
         if (jdbcSinkConfig.isExactlyOnce()) {
             return new JdbcExactlyOnceSinkWriter(
-                    context, jobContext, dialect, jdbcSinkConfig, tableSchema, states);
+                    sinkTablePath,
+                    context,
+                    jobContext,
+                    dialect,
+                    jdbcSinkConfig,
+                    tableSchema,
+                    states);
         }
         return SeaTunnelSink.super.restoreWriter(context, states);
     }
@@ -165,6 +177,11 @@ public class JdbcSink
 
     @Override
     public Optional<SaveModeHandler> getSaveModeHandler() {
+        try {
+            Class.forName(jdbcSinkConfig.getJdbcConnectionConfig().getDriverName());
+        } catch (ClassNotFoundException e) {
+            throw new RuntimeException(e);
+        }
         if (catalogTable != null) {
             if (StringUtils.isBlank(jdbcSinkConfig.getDatabase())) {
                 return Optional.empty();
@@ -194,6 +211,16 @@ public class JdbcSink
                                     CatalogUtils.quoteTableIdentifier(
                                             catalogTable.getTableId().getTableName(), fieldIde));
                     catalogTable.getOptions().put("fieldIde", fieldIde);
+                    if (catalog instanceof IrisCatalog) {
+                        return Optional.of(
+                                new IrisSaveModeHandler(
+                                        schemaSaveMode,
+                                        dataSaveMode,
+                                        catalog,
+                                        tablePath,
+                                        catalogTable,
+                                        config.get(JdbcOptions.CUSTOM_SQL)));
+                    }
                     return Optional.of(
                             new DefaultSaveModeHandler(
                                     schemaSaveMode,
