@@ -25,6 +25,7 @@ import org.apache.seatunnel.api.table.connector.TableSink;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactoryContext;
+import org.apache.seatunnel.connectors.seatunnel.paimon.catalog.PaimonCatalogEnum;
 import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonConfig;
 import org.apache.seatunnel.connectors.seatunnel.paimon.config.PaimonSinkConfig;
 
@@ -35,12 +36,6 @@ import com.google.auto.service.AutoService;
 @AutoService(Factory.class)
 public class PaimonSinkFactory implements TableSinkFactory {
 
-    public static final String REPLACE_TABLE_NAME_KEY = "${table_name}";
-
-    public static final String REPLACE_SCHEMA_NAME_KEY = "${schema_name}";
-
-    public static final String REPLACE_DATABASE_NAME_KEY = "${database_name}";
-
     @Override
     public String factoryIdentifier() {
         return "Paimon";
@@ -52,13 +47,16 @@ public class PaimonSinkFactory implements TableSinkFactory {
                 .required(PaimonConfig.WAREHOUSE, PaimonConfig.DATABASE, PaimonConfig.TABLE)
                 .optional(
                         PaimonConfig.HDFS_SITE_PATH,
+                        PaimonConfig.HADOOP_CONF,
+                        PaimonConfig.HADOOP_CONF_PATH,
+                        PaimonConfig.CATALOG_TYPE,
                         PaimonSinkConfig.SCHEMA_SAVE_MODE,
                         PaimonSinkConfig.DATA_SAVE_MODE,
                         PaimonSinkConfig.PRIMARY_KEYS,
                         PaimonSinkConfig.PARTITION_KEYS,
-                        PaimonSinkConfig.WRITE_PROPS,
-                        PaimonConfig.HADOOP_CONF,
-                        PaimonConfig.HADOOP_CONF_PATH)
+                        PaimonSinkConfig.WRITE_PROPS)
+                .conditional(
+                        PaimonConfig.CATALOG_TYPE, PaimonCatalogEnum.HIVE, PaimonConfig.CATALOG_URI)
                 .build();
     }
 
@@ -76,13 +74,13 @@ public class PaimonSinkFactory implements TableSinkFactory {
         String tableName;
         String namespace;
         if (StringUtils.isNotEmpty(paimonSinkConfig.getTable())) {
-            tableName = replaceName(paimonSinkConfig.getTable(), tableId);
+            tableName = paimonSinkConfig.getTable();
         } else {
             tableName = tableId.getTableName();
         }
 
         if (StringUtils.isNotEmpty(paimonSinkConfig.getNamespace())) {
-            namespace = replaceName(paimonSinkConfig.getNamespace(), tableId);
+            namespace = paimonSinkConfig.getNamespace();
         } else {
             namespace = tableId.getSchemaName();
         }
@@ -93,17 +91,4 @@ public class PaimonSinkFactory implements TableSinkFactory {
 
         return CatalogTable.of(newTableId, catalogTable);
     }
-
-    private String replaceName(String original, TableIdentifier tableId) {
-        if (tableId.getTableName() != null) {
-            original = original.replace(REPLACE_TABLE_NAME_KEY, tableId.getTableName());
-        }
-        if (tableId.getSchemaName() != null) {
-            original = original.replace(REPLACE_SCHEMA_NAME_KEY, tableId.getSchemaName());
-        }
-        if (tableId.getDatabaseName() != null) {
-            original = original.replace(REPLACE_DATABASE_NAME_KEY, tableId.getDatabaseName());
-        }
-        return original;
-    }
 }
