@@ -44,7 +44,9 @@ public abstract class AbstractCommandArgs extends CommandArgs {
             splitter = ParameterSplitter.class,
             description =
                     "Variable substitution, such as -i city=beijing, or -i date=20190318."
-                            + "We use ',' as separator, when inside \"\", ',' are treated as normal characters instead of delimiters.")
+                            + "We use ',' as separator, when inside \"\", ',' are treated as normal characters instead of delimiters."
+                            + " For example, -i city=\"beijing,shanghai\". If you want to use dynamic parameters,"
+                            + " you can use the following format: -i date=$(date +\"%Y%m%d\").")
     protected List<String> variables = Collections.emptyList();
 
     /** check config flag */
