@@ -23,14 +23,18 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.catalog.TablePath;
+import org.apache.seatunnel.api.table.converter.BasicTypeDefine;
 import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.catalog.ElasticSearchCatalog;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.client.EsRestClient;
+import org.apache.seatunnel.connectors.seatunnel.elasticsearch.client.EsType;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.dto.BulkResponse;
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.dto.source.ScrollResult;
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
+import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
+import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.util.ContainerUtil;
 
 import org.apache.commons.io.IOUtils;
@@ -48,6 +52,7 @@ import org.testcontainers.utility.DockerImageName;
 import org.testcontainers.utility.DockerLoggerFactory;
 
 import com.google.common.collect.Lists;
+import com.google.common.collect.Maps;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
@@ -57,6 +62,7 @@ import java.time.Duration;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.ZoneOffset;
+import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -111,6 +117,7 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         testDataset = generateTestDataSet();
         createIndexDocs();
         createIndexWithFullType();
+        createIndexForResourceNull();
     }
 
     /** create a index,and bulk some documents */
@@ -156,17 +163,70 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                 2, esRestClient.getIndexDocsCount("st_index_full_type").get(0).getDocsCount());
     }
 
+    private void createIndexForResourceNull() throws IOException {
+        String mapping =
+                IOUtils.toString(
+                        ContainerUtil.getResourcesFile(
+                                        "/elasticsearch/st_index_source_without_schema_and_sink.json")
+                                .toURI(),
+                        StandardCharsets.UTF_8);
+        esRestClient.createIndex("st_index4", mapping);
+    }
+
     @TestTemplate
     public void testElasticsearch(TestContainer container)
             throws IOException, InterruptedException {
         Container.ExecResult execResult =
                 container.executeJob("/elasticsearch/elasticsearch_source_and_sink.conf");
         Assertions.assertEquals(0, execResult.getExitCode());
-        List<String> sinkData = readSinkData();
+        List<String> sinkData = readSinkData("st_index2");
         // for DSL is: {"range":{"c_int":{"gte":10,"lte":20}}}
         Assertions.assertIterableEquals(mapTestDatasetForDSL(), sinkData);
     }
 
+    @DisabledOnContainer(
+            value = {},
+            type = {EngineType.SPARK, EngineType.FLINK},
+            disabledReason = "Currently SPARK/FLINK do not support multiple table read")
+    @TestTemplate
+    public void testElasticsearchWithMultiSink(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/elasticsearch/fakesource_to_elasticsearch_multi_sink.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+        List<String> source5 =
+                Lists.newArrayList(
+                        "id",
+                        "c_bool",
+                        "c_tinyint",
+                        "c_smallint",
+                        "c_int",
+                        "c_bigint",
+                        "c_float",
+                        "c_double",
+                        "c_decimal",
+                        "c_string");
+        List<String> source6 =
+                Lists.newArrayList(
+                        "id",
+                        "c_bool",
+                        "c_tinyint",
+                        "c_smallint",
+                        "c_int",
+                        "c_bigint",
+                        "c_float",
+                        "c_double",
+                        "c_decimal");
+        List<String> sinkIndexData5 = readMultiSinkData("st_index5", source5);
+        List<String> sinkIndexData6 = readMultiSinkData("st_index6", source6);
+        String stIndex5 =
+                "{\"c_smallint\":2,\"c_string\":\"NEW\",\"c_float\":4.3,\"c_double\":5.3,\"c_decimal\":6.3,\"id\":1,\"c_int\":3,\"c_bigint\":4,\"c_bool\":true,\"c_tinyint\":1}";
+        String stIndex6 =
+                "{\"c_smallint\":2,\"c_float\":4.3,\"c_double\":5.3,\"c_decimal\":6.3,\"id\":1,\"c_int\":3,\"c_bigint\":4,\"c_bool\":true,\"c_tinyint\":1}";
+        Assertions.assertIterableEquals(Lists.newArrayList(stIndex5), sinkIndexData5);
+        Assertions.assertIterableEquals(Lists.newArrayList(stIndex6), sinkIndexData6);
+    }
+
     @TestTemplate
     public void testElasticsearchWithFullType(TestContainer container)
             throws IOException, InterruptedException {
@@ -179,6 +239,19 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                 esRestClient.getIndexDocsCount("st_index_full_type_target").get(0).getDocsCount());
     }
 
+    @TestTemplate
+    public void testElasticsearchWithoutSchema(TestContainer container)
+            throws IOException, InterruptedException {
+
+        Container.ExecResult execResult =
+                container.executeJob(
+                        "/elasticsearch/elasticsearch_source_without_schema_and_sink.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+        List<String> sinkData = readSinkDataWithOutSchema();
+        // for DSL is: {"range":{"c_int":{"gte":10,"lte":20}}}
+        Assertions.assertIterableEquals(mapTestDatasetForDSL(), sinkData);
+    }
+
     private List<String> generateTestDataSet() throws JsonProcessingException {
         String[] fields =
                 new String[] {
@@ -188,12 +261,12 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                     "c_boolean",
                     "c_tinyint",
                     "c_smallint",
-                    "c_int",
                     "c_bigint",
                     "c_float",
                     "c_double",
                     "c_decimal",
                     "c_bytes",
+                    "c_int",
                     "c_date",
                     "c_timestamp"
                 };
@@ -227,7 +300,15 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         return documents;
     }
 
-    private List<String> readSinkData() throws InterruptedException {
+    private List<String> readSinkDataWithOutSchema() throws InterruptedException {
+        Map<String, BasicTypeDefine<EsType>> esFieldType =
+                esRestClient.getFieldTypeMapping("st_index4", Lists.newArrayList());
+        Thread.sleep(2000);
+        List<String> source = new ArrayList<>(esFieldType.keySet());
+        return getDocsWithTransformDate(source, "st_index4");
+    }
+
+    private List<String> readSinkData(String index) throws InterruptedException {
         // wait for index refresh
         Thread.sleep(2000);
         List<String> source =
@@ -238,23 +319,52 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                         "c_boolean",
                         "c_tinyint",
                         "c_smallint",
-                        "c_int",
                         "c_bigint",
                         "c_float",
                         "c_double",
                         "c_decimal",
                         "c_bytes",
+                        "c_int",
                         "c_date",
                         "c_timestamp");
-        HashMap<String, Object> rangeParam = new HashMap<>();
-        rangeParam.put("gte", 10);
-        rangeParam.put("lte", 20);
-        HashMap<String, Object> range = new HashMap<>();
-        range.put("c_int", rangeParam);
+        return getDocsWithTransformTimestamp(source, index);
+    }
+
+    private List<String> readMultiSinkData(String index, List<String> source)
+            throws InterruptedException {
+        // wait for index refresh
+        Thread.sleep(2000);
         Map<String, Object> query = new HashMap<>();
+        query.put("match_all", Maps.newHashMap());
+
+        ScrollResult scrollResult = esRestClient.searchByScroll(index, source, query, "1m", 1000);
+        scrollResult
+                .getDocs()
+                .forEach(
+                        x -> {
+                            x.remove("_index");
+                            x.remove("_type");
+                            x.remove("_id");
+                        });
+        List<String> docs =
+                scrollResult.getDocs().stream()
+                        .sorted(
+                                Comparator.comparingInt(
+                                        o -> Integer.valueOf(o.get("c_int").toString())))
+                        .map(JsonUtils::toJsonString)
+                        .collect(Collectors.toList());
+        return docs;
+    }
+
+    private List<String> getDocsWithTransformTimestamp(List<String> source, String index) {
+        HashMap<String, Object> rangeParam = new HashMap<>();
+        rangeParam.put("gte", 10);
+        rangeParam.put("lte", 20);
+        HashMap<String, Object> range = new HashMap<>();
+        range.put("c_int", rangeParam);
+        Map<String, Object> query = new HashMap<>();
         query.put("range", range);
-        ScrollResult scrollResult =
-                esRestClient.searchByScroll("st_index2", source, query, "1m", 1000);
+        ScrollResult scrollResult = esRestClient.searchByScroll(index, source, query, "1m", 1000);
         scrollResult
                 .getDocs()
                 .forEach(
@@ -262,8 +372,6 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                             x.remove("_index");
                             x.remove("_type");
                             x.remove("_id");
-                            // I don’t know if converting the test cases in this way complies with
-                            // the CI specification
                             x.replace(
                                     "c_timestamp",
                                     LocalDateTime.parse(x.get("c_timestamp").toString())
@@ -280,6 +388,40 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         return docs;
     }
 
+    private List<String> getDocsWithTransformDate(List<String> source, String index) {
+        HashMap<String, Object> rangeParam = new HashMap<>();
+        rangeParam.put("gte", 10);
+        rangeParam.put("lte", 20);
+        HashMap<String, Object> range = new HashMap<>();
+        range.put("c_int", rangeParam);
+        Map<String, Object> query = new HashMap<>();
+        query.put("range", range);
+        ScrollResult scrollResult = esRestClient.searchByScroll(index, source, query, "1m", 1000);
+        scrollResult
+                .getDocs()
+                .forEach(
+                        x -> {
+                            x.remove("_index");
+                            x.remove("_type");
+                            x.remove("_id");
+                            x.replace(
+                                    "c_date",
+                                    LocalDate.parse(
+                                                    x.get("c_date").toString(),
+                                                    DateTimeFormatter.ofPattern(
+                                                            "yyyy-MM-dd'T'HH:mm"))
+                                            .toString());
+                        });
+        List<String> docs =
+                scrollResult.getDocs().stream()
+                        .sorted(
+                                Comparator.comparingInt(
+                                        o -> Integer.valueOf(o.get("c_int").toString())))
+                        .map(JsonUtils::toJsonString)
+                        .collect(Collectors.toList());
+        return docs;
+    }
+
     private List<String> mapTestDatasetForDSL() {
         return testDataset.stream()
                 .map(JsonUtils::parseObject)
@@ -305,35 +447,78 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
     }
 
     @Test
-    public void testCatalog() {
+    public void testCatalog() throws InterruptedException, JsonProcessingException {
         Map<String, Object> configMap = new HashMap<>();
         configMap.put("username", "elastic");
         configMap.put("password", "elasticsearch");
-        configMap.put("hosts", Arrays.asList("https://" + container.getHttpHostAddress()));
+        configMap.put(
+                "hosts", Collections.singletonList("https://" + container.getHttpHostAddress()));
         configMap.put("index", "st_index3");
         configMap.put("tls_verify_certificate", false);
         configMap.put("tls_verify_hostname", false);
         configMap.put("index_type", "st");
+
         final ElasticSearchCatalog elasticSearchCatalog =
                 new ElasticSearchCatalog("Elasticsearch", "", ReadonlyConfig.fromMap(configMap));
         elasticSearchCatalog.open();
+
         TablePath tablePath = TablePath.of("", "st_index3");
-        // index exists
+
+        // Verify index does not exist initially
         final boolean existsBefore = elasticSearchCatalog.tableExists(tablePath);
-        Assertions.assertFalse(existsBefore);
-        // create index
+        Assertions.assertFalse(existsBefore, "Index should not exist initially");
+
+        // Create index
         elasticSearchCatalog.createTable(tablePath, null, false);
         final boolean existsAfter = elasticSearchCatalog.tableExists(tablePath);
-        Assertions.assertTrue(existsAfter);
-        // data exists?
-        final boolean existsData = elasticSearchCatalog.isExistsData(tablePath);
-        Assertions.assertFalse(existsData);
-        // truncate
+        Assertions.assertTrue(existsAfter, "Index should be created");
+
+        // Generate and add multiple records
+        List<String> data = generateTestData();
+        StringBuilder requestBody = new StringBuilder();
+        String indexHeader = "{\"index\":{\"_index\":\"st_index3\"}}\n";
+        for (String record : data) {
+            requestBody.append(indexHeader);
+            requestBody.append(record);
+            requestBody.append("\n");
+        }
+        esRestClient.bulk(requestBody.toString());
+        Thread.sleep(2000); // Wait for data to be indexed
+
+        // Verify data exists
+        List<String> sourceFields = Arrays.asList("field1", "field2");
+        Map<String, Object> query = new HashMap<>();
+        query.put("match_all", new HashMap<>());
+        ScrollResult scrollResult =
+                esRestClient.searchByScroll("st_index3", sourceFields, query, "1m", 100);
+        Assertions.assertFalse(scrollResult.getDocs().isEmpty(), "Data should exist in the index");
+
+        // Truncate the table
         elasticSearchCatalog.truncateTable(tablePath, false);
-        Assertions.assertTrue(elasticSearchCatalog.tableExists(tablePath));
-        // drop
+        Thread.sleep(2000); // Wait for data to be indexed
+
+        // Verify data is deleted
+        scrollResult = esRestClient.searchByScroll("st_index3", sourceFields, query, "1m", 100);
+        Assertions.assertTrue(
+                scrollResult.getDocs().isEmpty(), "Data should be deleted from the index");
+
+        // Drop the table
         elasticSearchCatalog.dropTable(tablePath, false);
-        Assertions.assertFalse(elasticSearchCatalog.tableExists(tablePath));
+        Assertions.assertFalse(
+                elasticSearchCatalog.tableExists(tablePath), "Index should be dropped");
+
         elasticSearchCatalog.close();
     }
+
+    private List<String> generateTestData() throws JsonProcessingException {
+        List<String> data = new ArrayList<>();
+        ObjectMapper objectMapper = new ObjectMapper();
+        for (int i = 0; i < 10; i++) {
+            Map<String, Object> record = new HashMap<>();
+            record.put("field1", "value" + i);
+            record.put("field2", i);
+            data.add(objectMapper.writeValueAsString(record));
+        }
+        return data;
+    }
 }
