@@ -193,19 +193,21 @@ public abstract class AbstractJdbcIT extends TestSuiteBase implements TestResour
                                     jdbcCase.getDatabase(),
                                     jdbcCase.getSchema(),
                                     jdbcCase.getSourceTable()));
-            if (jdbcCase.getSinkCreateSql() != null) {
-                createTemplate = jdbcCase.getSinkCreateSql();
-            }
-            String createSink =
-                    String.format(
-                            createTemplate,
-                            buildTableInfoWithSchema(
-                                    jdbcCase.getDatabase(),
-                                    jdbcCase.getSchema(),
-                                    jdbcCase.getSinkTable()));
-
             statement.execute(createSource);
-            statement.execute(createSink);
+
+            if (!jdbcCase.isUseSaveModeCreateTable()) {
+                if (jdbcCase.getSinkCreateSql() != null) {
+                    createTemplate = jdbcCase.getSinkCreateSql();
+                }
+                String createSink =
+                        String.format(
+                                createTemplate,
+                                buildTableInfoWithSchema(
+                                        jdbcCase.getDatabase(),
+                                        jdbcCase.getSchema(),
+                                        jdbcCase.getSinkTable()));
+                statement.execute(createSink);
+            }
 
             connection.commit();
         } catch (Exception exception) {
@@ -407,6 +409,10 @@ public abstract class AbstractJdbcIT extends TestSuiteBase implements TestResour
             try (InputStream inputStream = ((Blob) data).getBinaryStream()) {
                 return ByteStreams.toByteArray(inputStream);
             }
+        } else if (data instanceof InputStream) {
+            try (InputStream inputStream = (InputStream) data) {
+                return ByteStreams.toByteArray(inputStream);
+            }
         } else if (data instanceof Array) {
             Object[] jdbcArray = (Object[]) ((Array) data).getArray();
             Object[] javaArray = new Object[jdbcArray.length];
