@@ -67,6 +67,7 @@ import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -95,7 +96,9 @@ public class JdbcMysqlIT extends AbstractJdbcIT {
             Lists.newArrayList(
                     "/jdbc_mysql_source_and_sink.conf",
                     "/jdbc_mysql_source_and_sink_parallel.conf",
-                    "/jdbc_mysql_source_and_sink_parallel_upper_lower.conf");
+                    "/jdbc_mysql_source_and_sink_parallel_upper_lower.conf",
+                    "/jdbc_mysql_source_and_sink.sql",
+                    "/jdbc_mysql_source_and_sink_parallel.sql");
     private static final String CREATE_SQL =
             "CREATE TABLE IF NOT EXISTS %s\n"
                     + "(\n"
@@ -477,8 +480,11 @@ public class JdbcMysqlIT extends AbstractJdbcIT {
         map1.put("url", getUrl());
         ReadonlyConfig config1 = ReadonlyConfig.fromMap(map1);
         TableSinkFactoryContext context1 =
-                new TableSinkFactoryContext(
-                        catalogTable, config1, Thread.currentThread().getContextClassLoader());
+                TableSinkFactoryContext.replacePlaceholderAndCreate(
+                        catalogTable,
+                        config1,
+                        Thread.currentThread().getContextClassLoader(),
+                        Collections.emptyList());
         JdbcSink jdbcSink1 = (JdbcSink) new JdbcSinkFactory().createSink(context1).createSink();
         Properties connectionProperties1 = getSinkProperties(jdbcSink1);
         Assertions.assertEquals(connectionProperties1.get("rewriteBatchedStatements"), "true");
@@ -488,8 +494,11 @@ public class JdbcMysqlIT extends AbstractJdbcIT {
         map2.put("url", getUrl() + "?rewriteBatchedStatements=false");
         ReadonlyConfig config2 = ReadonlyConfig.fromMap(map2);
         TableSinkFactoryContext context2 =
-                new TableSinkFactoryContext(
-                        catalogTable, config2, Thread.currentThread().getContextClassLoader());
+                TableSinkFactoryContext.replacePlaceholderAndCreate(
+                        catalogTable,
+                        config2,
+                        Thread.currentThread().getContextClassLoader(),
+                        Collections.emptyList());
         JdbcSink jdbcSink2 = (JdbcSink) new JdbcSinkFactory().createSink(context2).createSink();
         Properties connectionProperties2 = getSinkProperties(jdbcSink2);
         Assertions.assertEquals(connectionProperties2.get("rewriteBatchedStatements"), "false");
@@ -502,8 +511,11 @@ public class JdbcMysqlIT extends AbstractJdbcIT {
         map3.put("url", getUrl());
         ReadonlyConfig config3 = ReadonlyConfig.fromMap(map3);
         TableSinkFactoryContext context3 =
-                new TableSinkFactoryContext(
-                        catalogTable, config3, Thread.currentThread().getContextClassLoader());
+                TableSinkFactoryContext.replacePlaceholderAndCreate(
+                        catalogTable,
+                        config3,
+                        Thread.currentThread().getContextClassLoader(),
+                        Collections.emptyList());
         JdbcSink jdbcSink3 = (JdbcSink) new JdbcSinkFactory().createSink(context3).createSink();
         Properties connectionProperties3 = getSinkProperties(jdbcSink3);
         Assertions.assertEquals(connectionProperties3.get("rewriteBatchedStatements"), "false");
@@ -517,8 +529,11 @@ public class JdbcMysqlIT extends AbstractJdbcIT {
         map4.put("url", getUrl() + "?useSSL=false&rewriteBatchedStatements=true");
         ReadonlyConfig config4 = ReadonlyConfig.fromMap(map4);
         TableSinkFactoryContext context4 =
-                new TableSinkFactoryContext(
-                        catalogTable, config4, Thread.currentThread().getContextClassLoader());
+                TableSinkFactoryContext.replacePlaceholderAndCreate(
+                        catalogTable,
+                        config4,
+                        Thread.currentThread().getContextClassLoader(),
+                        Collections.emptyList());
         JdbcSink jdbcSink4 = (JdbcSink) new JdbcSinkFactory().createSink(context4).createSink();
         Properties connectionProperties4 = getSinkProperties(jdbcSink4);
         Assertions.assertEquals(connectionProperties4.get("useSSL"), "true");
