@@ -28,6 +28,7 @@ import org.apache.seatunnel.connectors.seatunnel.jdbc.source.JdbcSourceTable;
 
 import org.apache.commons.lang3.tuple.Pair;
 
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.testcontainers.containers.GenericContainer;
 import org.testcontainers.containers.OracleContainer;
@@ -40,7 +41,7 @@ import com.google.common.collect.Lists;
 
 import java.math.BigDecimal;
 import java.sql.Date;
-import java.sql.SQLException;
+import java.sql.Statement;
 import java.sql.Timestamp;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
@@ -64,7 +65,11 @@ public class JdbcOracleIT extends AbstractJdbcIT {
     private static final String SINK_TABLE = "E2E_TABLE_SINK";
     private static final String CATALOG_TABLE = "E2E_TABLE_CATALOG";
     private static final List<String> CONFIG_FILE =
-            Lists.newArrayList("/jdbc_oracle_source_to_sink.conf");
+            Lists.newArrayList(
+                    "/jdbc_oracle_source_to_sink.conf",
+                    "/jdbc_oracle_source_to_sink_use_select1.conf",
+                    "/jdbc_oracle_source_to_sink_use_select2.conf",
+                    "/jdbc_oracle_source_to_sink_use_select3.conf");
 
     private static final String CREATE_SQL =
             "create table %s\n"
@@ -73,6 +78,7 @@ public class JdbcOracleIT extends AbstractJdbcIT {
                     + "    CHAR_10_COL                   char(10),\n"
                     + "    CLOB_COL                      clob,\n"
                     + "    NUMBER_3_SF_2_DP              number(3, 2),\n"
+                    + "    NUMBER_7_SF_N2_DP             number(7, -2),\n"
                     + "    INTEGER_COL                   integer,\n"
                     + "    FLOAT_COL                     float(10),\n"
                     + "    REAL_COL                      real,\n"
@@ -90,6 +96,7 @@ public class JdbcOracleIT extends AbstractJdbcIT {
                 "CHAR_10_COL",
                 "CLOB_COL",
                 "NUMBER_3_SF_2_DP",
+                "NUMBER_7_SF_N2_DP",
                 "INTEGER_COL",
                 "FLOAT_COL",
                 "REAL_COL",
@@ -102,7 +109,7 @@ public class JdbcOracleIT extends AbstractJdbcIT {
             };
 
     @Test
-    public void testSampleDataFromColumnSuccess() throws SQLException {
+    public void testSampleDataFromColumnSuccess() throws Exception {
         JdbcDialect dialect = new OracleDialect();
         JdbcSourceTable table =
                 JdbcSourceTable.builder()
@@ -162,7 +169,7 @@ public class JdbcOracleIT extends AbstractJdbcIT {
     @Override
     Pair<String[], List<SeaTunnelRow>> initTestData() {
         List<SeaTunnelRow> rows = new ArrayList<>();
-        for (int i = 0; i < 100; i++) {
+        for (int i = 0; i < 20000; i++) {
             SeaTunnelRow row =
                     new SeaTunnelRow(
                             new Object[] {
@@ -170,6 +177,7 @@ public class JdbcOracleIT extends AbstractJdbcIT {
                                 String.format("f%s", i),
                                 String.format("f%s", i),
                                 BigDecimal.valueOf(1.1),
+                                BigDecimal.valueOf(2400),
                                 i,
                                 Float.parseFloat("2.2"),
                                 Float.parseFloat("2.2"),
@@ -235,4 +243,22 @@ public class JdbcOracleIT extends AbstractJdbcIT {
                         SCHEMA);
         catalog.open();
     }
+
+    @BeforeAll
+    @Override
+    public void startUp() {
+        super.startUp();
+        // analyzeTable before execute job
+        String analyzeTable =
+                String.format(
+                        "analyze table "
+                                + quoteIdentifier(SOURCE_TABLE)
+                                + " compute statistics for table");
+        log.info("analyze table {}", analyzeTable);
+        try (Statement stmt = connection.createStatement()) {
+            stmt.execute(analyzeTable);
+        } catch (Exception e) {
+            log.error("Error when analyze table", e);
+        }
+    }
 }
