@@ -335,31 +335,40 @@ public class JdbcSqlServerIT extends AbstractJdbcIT {
     @Test
     public void testCatalog() {
         TablePath tablePathSqlserver = TablePath.of("master", "dbo", "source");
-        TablePath tablePathSqlserver_Sink = TablePath.of("master", "dbo", "sink_lw");
+        TablePath tablePathSqlserverSink = TablePath.of("master", "dbo", "sink_lw");
         SqlServerCatalog sqlServerCatalog = (SqlServerCatalog) catalog;
+        // add comment
+        sqlServerCatalog.executeSql(
+                tablePathSqlserver,
+                "execute sp_addextendedproperty 'MS_Description','\"#¥%……&*();\\\\;'',,..``````//''@Xx''\\''\"','user','dbo','table','source','column','BIGINT_TEST';");
         CatalogTable catalogTable = sqlServerCatalog.getTable(tablePathSqlserver);
         // sink tableExists ?
-        boolean tableExistsBefore = sqlServerCatalog.tableExists(tablePathSqlserver_Sink);
+        boolean tableExistsBefore = sqlServerCatalog.tableExists(tablePathSqlserverSink);
         Assertions.assertFalse(tableExistsBefore);
         // create table
-        sqlServerCatalog.createTable(tablePathSqlserver_Sink, catalogTable, true);
-        boolean tableExistsAfter = sqlServerCatalog.tableExists(tablePathSqlserver_Sink);
+        sqlServerCatalog.createTable(tablePathSqlserverSink, catalogTable, true);
+        boolean tableExistsAfter = sqlServerCatalog.tableExists(tablePathSqlserverSink);
         Assertions.assertTrue(tableExistsAfter);
+        // comment
+        final CatalogTable sinkTable = sqlServerCatalog.getTable(tablePathSqlserverSink);
+        Assertions.assertEquals(
+                sinkTable.getTableSchema().getColumns().get(1).getComment(),
+                "\"#¥%……&*();\\\\;',,..``````//'@Xx'\\'\"");
         // isExistsData ?
-        boolean existsDataBefore = sqlServerCatalog.isExistsData(tablePathSqlserver_Sink);
+        boolean existsDataBefore = sqlServerCatalog.isExistsData(tablePathSqlserverSink);
         Assertions.assertFalse(existsDataBefore);
         // insert one data
         sqlServerCatalog.executeSql(
-                tablePathSqlserver_Sink,
+                tablePathSqlserverSink,
                 "insert into sink_lw(INT_IDENTITY_TEST, BIGINT_TEST) values(1, 12)");
-        boolean existsDataAfter = sqlServerCatalog.isExistsData(tablePathSqlserver_Sink);
+        boolean existsDataAfter = sqlServerCatalog.isExistsData(tablePathSqlserverSink);
         Assertions.assertTrue(existsDataAfter);
         // truncateTable
-        sqlServerCatalog.truncateTable(tablePathSqlserver_Sink, true);
-        Assertions.assertFalse(sqlServerCatalog.isExistsData(tablePathSqlserver_Sink));
+        sqlServerCatalog.truncateTable(tablePathSqlserverSink, true);
+        Assertions.assertFalse(sqlServerCatalog.isExistsData(tablePathSqlserverSink));
         // drop table
-        sqlServerCatalog.dropTable(tablePathSqlserver_Sink, true);
-        Assertions.assertFalse(sqlServerCatalog.tableExists(tablePathSqlserver_Sink));
+        sqlServerCatalog.dropTable(tablePathSqlserverSink, true);
+        Assertions.assertFalse(sqlServerCatalog.tableExists(tablePathSqlserverSink));
         sqlServerCatalog.close();
     }
 }
