@@ -18,6 +18,7 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc;
 
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.connectors.seatunnel.jdbc.catalog.oracle.OracleCatalog;
@@ -221,6 +222,8 @@ public class JdbcOracleLowercaseTableIT extends AbstractJdbcIT {
     @Test
     public void testCatalog() {
         TablePath tablePathOracle = TablePath.of("XE", "TESTUSER", "E2E_TABLE_SOURCE_LOWER");
+        TablePath tablePathOracleCreateTablePath =
+                TablePath.of("XE", "TESTUSER", "E2E_TABLE_SOURCE_LOWER_AUTO");
         OracleCatalog oracleCatalog =
                 new OracleCatalog(
                         "Oracle",
@@ -230,9 +233,29 @@ public class JdbcOracleLowercaseTableIT extends AbstractJdbcIT {
                                 jdbcCase.getJdbcUrl().replace(HOST, dbServer.getHost())),
                         SCHEMA);
         oracleCatalog.open();
+        catalog.executeSql(
+                tablePathOracle,
+                "comment on column E2E_TABLE_SOURCE_LOWER.CHAR_10_COL is '\"#¥%……&*（）;;'',,..``````//''@特殊注释''\\''\"'");
         Assertions.assertTrue(oracleCatalog.tableExists(tablePathOracle));
+        Assertions.assertEquals(
+                oracleCatalog
+                        .getTable(tablePathOracle)
+                        .getTableSchema()
+                        .getColumns()
+                        .get(1)
+                        .getComment(),
+                "\"#¥%……&*（）;;',,..``````//'@特殊注释'\\'\"");
         oracleCatalog.truncateTable(tablePathOracle, true);
         Assertions.assertFalse(oracleCatalog.isExistsData(tablePathOracle));
+        // create table with comment
+        Assertions.assertFalse(oracleCatalog.tableExists(tablePathOracleCreateTablePath));
+        oracleCatalog.createTable(
+                tablePathOracleCreateTablePath, oracleCatalog.getTable(tablePathOracle), true);
+        Assertions.assertTrue(oracleCatalog.tableExists(tablePathOracleCreateTablePath));
+        final CatalogTable table = oracleCatalog.getTable(tablePathOracleCreateTablePath);
+        Assertions.assertEquals(
+                table.getTableSchema().getColumns().get(1).getComment(),
+                "\"#¥%……&*（）;;',,..``````//'@特殊注释'\\'\"");
         oracleCatalog.close();
     }
 }
