@@ -20,6 +20,8 @@ package org.apache.seatunnel.e2e.connector.kafka;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode;
 
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.CatalogTableUtil;
 import org.apache.seatunnel.api.table.type.ArrayType;
 import org.apache.seatunnel.api.table.type.BasicType;
 import org.apache.seatunnel.api.table.type.DecimalType;
@@ -210,6 +212,27 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
     }
 
+    @TestTemplate
+    public void testSourceKafkaToAssertWithMaxPollRecords1(TestContainer container)
+            throws IOException, InterruptedException {
+        TextSerializationSchema serializer =
+                TextSerializationSchema.builder()
+                        .seaTunnelRowType(SEATUNNEL_ROW_TYPE)
+                        .delimiter(",")
+                        .build();
+        generateTestData(
+                row ->
+                        new ProducerRecord<>(
+                                "test_topic_text_max_poll_records_1",
+                                null,
+                                serializer.serialize(row)),
+                0,
+                100);
+        Container.ExecResult execResult =
+                container.executeJob("/kafka/kafka_source_to_assert_with_max_poll_records_1.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+    }
+
     @TestTemplate
     public void testSourceKafkaTextToConsoleAssertCatalogTable(TestContainer container)
             throws IOException, InterruptedException {
@@ -370,8 +393,10 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
             subRow
         };
         SeaTunnelRowType fake_source_row_type = new SeaTunnelRowType(fieldNames, fieldTypes);
+        CatalogTable catalogTable =
+                CatalogTableUtil.getCatalogTable("", "", "", "", fake_source_row_type);
         AvroDeserializationSchema avroDeserializationSchema =
-                new AvroDeserializationSchema(fake_source_row_type);
+                new AvroDeserializationSchema(catalogTable);
         List<SeaTunnelRow> kafkaSTRow =
                 getKafkaSTRow(
                         "test_avro_topic_fake_source",
@@ -420,8 +445,11 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         Container.ExecResult execResult = container.executeJob("/avro/kafka_avro_to_assert.conf");
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
 
+        CatalogTable catalogTable =
+                CatalogTableUtil.getCatalogTable("", "", "", "", SEATUNNEL_ROW_TYPE);
+
         AvroDeserializationSchema avroDeserializationSchema =
-                new AvroDeserializationSchema(SEATUNNEL_ROW_TYPE);
+                new AvroDeserializationSchema(catalogTable);
         List<SeaTunnelRow> kafkaSTRow =
                 getKafkaSTRow(
                         "test_avro_topic",
@@ -531,29 +559,34 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
     }
 
     private void generateTestData(ProducerRecordConverter converter, int start, int end) {
-        for (int i = start; i < end; i++) {
-            SeaTunnelRow row =
-                    new SeaTunnelRow(
-                            new Object[] {
-                                Long.valueOf(i),
-                                Collections.singletonMap("key", Short.parseShort("1")),
-                                new Byte[] {Byte.parseByte("1")},
-                                "string",
-                                Boolean.FALSE,
-                                Byte.parseByte("1"),
-                                Short.parseShort("1"),
-                                Integer.parseInt("1"),
-                                Long.parseLong("1"),
-                                Float.parseFloat("1.1"),
-                                Double.parseDouble("1.1"),
-                                BigDecimal.valueOf(11, 1),
-                                "test".getBytes(),
-                                LocalDate.of(2024, 1, 1),
-                                LocalDateTime.of(2024, 1, 1, 12, 59, 23)
-                            });
-            ProducerRecord<byte[], byte[]> producerRecord = converter.convert(row);
-            producer.send(producerRecord);
+        try {
+            for (int i = start; i < end; i++) {
+                SeaTunnelRow row =
+                        new SeaTunnelRow(
+                                new Object[] {
+                                    Long.valueOf(i),
+                                    Collections.singletonMap("key", Short.parseShort("1")),
+                                    new Byte[] {Byte.parseByte("1")},
+                                    "string",
+                                    Boolean.FALSE,
+                                    Byte.parseByte("1"),
+                                    Short.parseShort("1"),
+                                    Integer.parseInt("1"),
+                                    Long.parseLong("1"),
+                                    Float.parseFloat("1.1"),
+                                    Double.parseDouble("1.1"),
+                                    BigDecimal.valueOf(11, 1),
+                                    "test".getBytes(),
+                                    LocalDate.of(2024, 1, 1),
+                                    LocalDateTime.of(2024, 1, 1, 12, 59, 23)
+                                });
+                ProducerRecord<byte[], byte[]> producerRecord = converter.convert(row);
+                producer.send(producerRecord).get();
+            }
+        } catch (Exception e) {
+            throw new RuntimeException(e);
         }
+        producer.flush();
     }
 
     private static final SeaTunnelRowType SEATUNNEL_ROW_TYPE =
