@@ -23,6 +23,7 @@ import org.testcontainers.containers.Container;
 import org.testcontainers.containers.Network;
 
 import java.io.IOException;
+import java.util.List;
 
 public interface TestContainer extends TestResource {
 
@@ -35,6 +36,9 @@ public interface TestContainer extends TestResource {
 
     Container.ExecResult executeJob(String confFile) throws IOException, InterruptedException;
 
+    Container.ExecResult executeJob(String confFile, List<String> variables)
+            throws IOException, InterruptedException;
+
     default Container.ExecResult executeConnectorCheck(String[] args)
             throws IOException, InterruptedException {
         throw new UnsupportedOperationException("Not implemented");
