@@ -70,6 +70,7 @@ import com.hazelcast.spi.impl.NodeEngineImpl;
 import lombok.NonNull;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -115,7 +116,7 @@ public class CoordinatorService {
      * <p>This IMap is used to recovery runningJobStateIMap in JobMaster when a new master node
      * active
      */
-    IMap<Object, Object> runningJobStateIMap;
+    private IMap<Object, Object> runningJobStateIMap;
 
     /**
      * IMap key is one of jobId {@link
@@ -130,13 +131,13 @@ public class CoordinatorService {
      * <p>This IMap is used to recovery runningJobStateTimestampsIMap in JobMaster when a new master
      * node active
      */
-    IMap<Object, Long[]> runningJobStateTimestampsIMap;
+    private IMap<Object, Long[]> runningJobStateTimestampsIMap;
 
     /**
      * key: job id; <br>
      * value: job master;
      */
-    private Map<Long, JobMaster> runningJobMasterMap = new ConcurrentHashMap<>();
+    private final Map<Long, JobMaster> runningJobMasterMap = new ConcurrentHashMap<>();
 
     /**
      * IMap key is {@link PipelineLocation}
@@ -165,6 +166,8 @@ public class CoordinatorService {
 
     private EventProcessor eventProcessor;
 
+    private PassiveCompletableFuture restoreAllJobFromMasterNodeSwitchFuture;
+
     public CoordinatorService(
             @NonNull NodeEngineImpl nodeEngine,
             @NonNull SeaTunnelServer seaTunnelServer,
@@ -210,8 +213,7 @@ public class CoordinatorService {
             handlers.add(httpReportHandler);
         }
         logger.info("Loaded event handlers: " + handlers);
-        JobEventProcessor eventProcessor = new JobEventProcessor(handlers);
-        return eventProcessor;
+        return new JobEventProcessor(handlers);
     }
 
     public JobHistoryService getJobHistoryService() {
@@ -226,24 +228,6 @@ public class CoordinatorService {
         return eventProcessor;
     }
 
-    // On the new master node
-    // 1. If runningJobStateIMap.get(jobId) == null and runningJobInfoIMap.get(jobId) != null. We
-    // will do
-    //    runningJobInfoIMap.remove(jobId)
-    //
-    // 2. If runningJobStateIMap.get(jobId) != null and the value equals JobStatus End State. We
-    // need new a
-    //    JobMaster and generate PhysicalPlan again and then try to remove all of PipelineLocation
-    // and
-    //    TaskGroupLocation key in the runningJobStateIMap.
-    //
-    // 3. If runningJobStateIMap.get(jobId) != null and the value equals JobStatus.SCHEDULED. We
-    // need cancel the job
-    //    and then call submitJob(long jobId, Data jobImmutableInformation) to resubmit it.
-    //
-    // 4. If runningJobStateIMap.get(jobId) != null and the value is CANCELING or RUNNING. We need
-    // recover the JobMaster
-    //    from runningJobStateIMap and then waiting for it complete.
     private void initCoordinatorService() {
         runningJobInfoIMap =
                 nodeEngine.getHazelcastInstance().getMap(Constant.IMAP_RUNNING_JOB_INFO);
@@ -281,8 +265,32 @@ public class CoordinatorService {
             connectorPackageService = new ConnectorPackageService(seaTunnelServer);
         }
 
-        List<CompletableFuture<Void>> collect =
+        restoreAllJobFromMasterNodeSwitchFuture =
+                new PassiveCompletableFuture(
+                        CompletableFuture.runAsync(
+                                this::restoreAllRunningJobFromMasterNodeSwitch, executorService));
+    }
+
+    private void restoreAllRunningJobFromMasterNodeSwitch() {
+        List<Map.Entry<Long, JobInfo>> needRestoreFromMasterNodeSwitchJobs =
                 runningJobInfoIMap.entrySet().stream()
+                        .filter(entry -> !runningJobMasterMap.keySet().contains(entry.getKey()))
+                        .collect(Collectors.toList());
+        if (needRestoreFromMasterNodeSwitchJobs.size() == 0) {
+            return;
+        }
+        // waiting have worker registered
+        while (getResourceManager().workerCount(Collections.emptyMap()) == 0) {
+            try {
+                logger.info("Waiting for worker registered");
+                Thread.sleep(1000);
+            } catch (InterruptedException e) {
+                logger.severe(ExceptionUtils.getMessage(e));
+                throw new SeaTunnelEngineException("wait worker register error", e);
+            }
+        }
+        List<CompletableFuture<Void>> collect =
+                needRestoreFromMasterNodeSwitchJobs.stream()
                         .map(
                                 entry ->
                                         CompletableFuture.runAsync(
@@ -292,8 +300,14 @@ public class CoordinatorService {
                                                                     "begin restore job (%s) from master active switch",
                                                                     entry.getKey()));
                                                     try {
-                                                        restoreJobFromMasterActiveSwitch(
-                                                                entry.getKey(), entry.getValue());
+                                                        // skip the job new submit
+                                                        if (!runningJobMasterMap
+                                                                .keySet()
+                                                                .contains(entry.getKey())) {
+                                                            restoreJobFromMasterActiveSwitch(
+                                                                    entry.getKey(),
+                                                                    entry.getValue());
+                                                        }
                                                     } catch (Exception e) {
                                                         logger.severe(e);
                                                     }
@@ -310,6 +324,7 @@ public class CoordinatorService {
                     CompletableFuture.allOf(collect.toArray(new CompletableFuture[0]));
             voidCompletableFuture.get();
         } catch (Exception e) {
+            logger.severe(ExceptionUtils.getMessage(e));
             throw new SeaTunnelEngineException(e);
         }
     }
@@ -427,7 +442,8 @@ public class CoordinatorService {
             synchronized (this) {
                 if (resourceManager == null) {
                     ResourceManager manager =
-                            new ResourceManagerFactory(nodeEngine).getResourceManager();
+                            new ResourceManagerFactory(nodeEngine, engineConfig)
+                                    .getResourceManager();
                     manager.init();
                     resourceManager = manager;
                 }
@@ -437,7 +453,8 @@ public class CoordinatorService {
     }
 
     /** call by client to submit job */
-    public PassiveCompletableFuture<Void> submitJob(long jobId, Data jobImmutableInformation) {
+    public PassiveCompletableFuture<Void> submitJob(
+            long jobId, Data jobImmutableInformation, boolean isStartWithSavePoint) {
         CompletableFuture<Void> jobSubmitFuture = new CompletableFuture<>();
 
         // Check if the current jobID is already running. If so, complete the submission
@@ -468,6 +485,13 @@ public class CoordinatorService {
         executorService.submit(
                 () -> {
                     try {
+                        if (!isStartWithSavePoint
+                                && getJobHistoryService().getJobMetrics(jobId) != null) {
+                            throw new JobException(
+                                    String.format(
+                                            "The job id %s has already been submitted and is not starting with a savepoint.",
+                                            jobId));
+                        }
                         runningJobInfoIMap.put(
                                 jobId,
                                 new JobInfo(System.currentTimeMillis(), jobImmutableInformation));
@@ -477,11 +501,9 @@ public class CoordinatorService {
                         // We specify that when init is complete, the submitJob is complete
                         jobSubmitFuture.complete(null);
                     } catch (Throwable e) {
-                        logger.severe(
-                                String.format(
-                                        "submit job %s error %s ",
-                                        jobId, ExceptionUtils.getMessage(e)));
-                        jobSubmitFuture.completeExceptionally(e);
+                        String errorMsg = ExceptionUtils.getMessage(e);
+                        logger.severe(String.format("submit job %s error %s ", jobId, errorMsg));
+                        jobSubmitFuture.completeExceptionally(new JobException(errorMsg));
                     }
                     if (!jobSubmitFuture.isCompletedExceptionally()) {
                         try {
@@ -516,7 +538,12 @@ public class CoordinatorService {
                             CompletableFuture.supplyAsync(
                                     () -> {
                                         JobMaster runningJobMaster = runningJobMasterMap.get(jobId);
-                                        runningJobMaster.savePoint().join();
+                                        if (!runningJobMaster.savePoint().join()) {
+                                            throw new SavePointFailedException(
+                                                    "The job with id '"
+                                                            + jobId
+                                                            + "' save point failed");
+                                        }
                                         return null;
                                     },
                                     executorService));
@@ -525,6 +552,8 @@ public class CoordinatorService {
     }
 
     public PassiveCompletableFuture<JobResult> waitForJobComplete(long jobId) {
+        // must wait for all job restore complete
+        restoreAllJobFromMasterNodeSwitchFuture.join();
         JobMaster runningJobMaster = runningJobMasterMap.get(jobId);
         if (runningJobMaster == null) {
             // Because operations on Imap cannot be performed within Operation.
