@@ -202,6 +202,7 @@ public class SeaTunnelHealthMonitor {
         public String render() {
             update();
             sb.setLength(0);
+            ipPort();
             renderProcessors();
             renderPhysicalMemory();
             renderSwap();
@@ -220,6 +221,11 @@ public class SeaTunnelHealthMonitor {
             return sb.toString();
         }
 
+        private void ipPort() {
+            sb.append("host=").append(node.address.getHost()).append(", ");
+            sb.append("port=").append(node.address.getPort()).append(", ");
+        }
+
         private void renderConnection() {
             sb.append("connection.active.count=")
                     .append(tcpConnectionActiveCount.read())
