@@ -17,8 +17,10 @@
 
 package org.apache.seatunnel.engine.server.resourcemanager.opeartion;
 
+import org.apache.seatunnel.common.utils.ExceptionUtils;
 import org.apache.seatunnel.engine.server.SeaTunnelServer;
 import org.apache.seatunnel.engine.server.resourcemanager.resource.SlotProfile;
+import org.apache.seatunnel.engine.server.resourcemanager.worker.WorkerProfile;
 import org.apache.seatunnel.engine.server.serializable.ResourceDataSerializerHook;
 import org.apache.seatunnel.engine.server.service.slot.WrongTargetSlotException;
 
@@ -35,6 +37,7 @@ public class ReleaseSlotOperation extends Operation implements IdentifiedDataSer
 
     private long jobID;
     private SlotProfile slotProfile;
+    private WorkerProfile result;
 
     public ReleaseSlotOperation() {}
 
@@ -50,10 +53,17 @@ public class ReleaseSlotOperation extends Operation implements IdentifiedDataSer
             server.getSlotService().releaseSlot(jobID, slotProfile);
         } catch (WrongTargetSlotException ignore) {
             log.warn(
-                    "wrong target release operation with job {} and slot profile {}",
+                    "wrong target release operation with job {} and slot profile {}, exception: {}",
                     jobID,
-                    slotProfile);
+                    slotProfile,
+                    ExceptionUtils.getMessage(ignore));
         }
+        result = server.getSlotService().getWorkerProfile();
+    }
+
+    @Override
+    public Object getResponse() {
+        return result;
     }
 
     @Override
