@@ -22,9 +22,12 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.JsonNode;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 
 import org.apache.seatunnel.api.common.metrics.JobMetrics;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.common.utils.DateTimeUtils;
 import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.engine.common.Constant;
+import org.apache.seatunnel.engine.common.env.EnvironmentUtil;
+import org.apache.seatunnel.engine.common.env.Version;
 import org.apache.seatunnel.engine.core.classloader.ClassLoaderService;
 import org.apache.seatunnel.engine.core.dag.logical.LogicalDag;
 import org.apache.seatunnel.engine.core.job.JobDAGInfo;
@@ -37,6 +40,8 @@ import org.apache.seatunnel.engine.server.master.JobHistoryService.JobState;
 import org.apache.seatunnel.engine.server.operation.GetClusterHealthMetricsOperation;
 import org.apache.seatunnel.engine.server.operation.GetJobMetricsOperation;
 import org.apache.seatunnel.engine.server.operation.GetJobStatusOperation;
+import org.apache.seatunnel.engine.server.resourcemanager.opeartion.GetOverviewOperation;
+import org.apache.seatunnel.engine.server.resourcemanager.resource.OverviewInfo;
 import org.apache.seatunnel.engine.server.utils.NodeEngineUtil;
 
 import com.hazelcast.cluster.Address;
@@ -53,16 +58,22 @@ import com.hazelcast.internal.util.StringUtil;
 import com.hazelcast.jet.impl.execution.init.CustomClassLoadedObject;
 import com.hazelcast.map.IMap;
 import com.hazelcast.spi.impl.NodeEngine;
+import com.hazelcast.spi.impl.NodeEngineImpl;
 
 import java.util.Arrays;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
+import java.util.Spliterators;
 import java.util.concurrent.ExecutionException;
+import java.util.stream.Collectors;
+import java.util.stream.StreamSupport;
 
 import static com.hazelcast.internal.ascii.rest.HttpStatusCode.SC_500;
 import static org.apache.seatunnel.engine.server.rest.RestConstant.FINISHED_JOBS_INFO;
+import static org.apache.seatunnel.engine.server.rest.RestConstant.JOB_INFO_URL;
+import static org.apache.seatunnel.engine.server.rest.RestConstant.OVERVIEW;
 import static org.apache.seatunnel.engine.server.rest.RestConstant.RUNNING_JOBS_URL;
 import static org.apache.seatunnel.engine.server.rest.RestConstant.RUNNING_JOB_URL;
 import static org.apache.seatunnel.engine.server.rest.RestConstant.RUNNING_THREADS;
@@ -70,12 +81,11 @@ import static org.apache.seatunnel.engine.server.rest.RestConstant.SYSTEM_MONITO
 
 public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCommand> {
 
-    private final Log4j2HttpGetCommandProcessor original;
-
     private static final String SOURCE_RECEIVED_COUNT = "SourceReceivedCount";
-
+    private static final String TABLE_SOURCE_RECEIVED_COUNT = "TableSourceReceivedCount";
     private static final String SINK_WRITE_COUNT = "SinkWriteCount";
-
+    private static final String TABLE_SINK_WRITE_COUNT = "TableSinkWriteCount";
+    private final Log4j2HttpGetCommandProcessor original;
     private NodeEngine nodeEngine;
 
     public RestHttpGetCommandProcessor(TextCommandService textCommandService) {
@@ -99,12 +109,14 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
                 handleRunningJobsInfo(httpGetCommand);
             } else if (uri.startsWith(FINISHED_JOBS_INFO)) {
                 handleFinishedJobsInfo(httpGetCommand, uri);
-            } else if (uri.startsWith(RUNNING_JOB_URL)) {
+            } else if (uri.startsWith(RUNNING_JOB_URL) || uri.startsWith(JOB_INFO_URL)) {
                 handleJobInfoById(httpGetCommand, uri);
             } else if (uri.startsWith(SYSTEM_MONITORING_INFORMATION)) {
                 getSystemMonitoringInformation(httpGetCommand);
             } else if (uri.startsWith(RUNNING_THREADS)) {
                 getRunningThread(httpGetCommand);
+            } else if (uri.startsWith(OVERVIEW)) {
+                overView(httpGetCommand, uri);
             } else {
                 original.handle(httpGetCommand);
             }
@@ -123,6 +135,47 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
         handle(httpGetCommand);
     }
 
+    public void overView(HttpGetCommand command, String uri) {
+        uri = StringUtil.stripTrailingSlash(uri);
+        String tagStr;
+        if (uri.contains("?")) {
+            int index = uri.indexOf("?");
+            tagStr = uri.substring(index + 1);
+        } else {
+            tagStr = "";
+        }
+        Map<String, String> tags =
+                Arrays.stream(tagStr.split("&"))
+                        .map(variable -> variable.split("=", 2))
+                        .filter(pair -> pair.length == 2)
+                        .collect(Collectors.toMap(pair -> pair[0], pair -> pair[1]));
+        Version version = EnvironmentUtil.getVersion();
+
+        SeaTunnelServer seaTunnelServer = getSeaTunnelServer(true);
+
+        OverviewInfo overviewInfo;
+
+        if (seaTunnelServer == null) {
+            overviewInfo =
+                    (OverviewInfo)
+                            NodeEngineUtil.sendOperationToMasterNode(
+                                            getNode().nodeEngine, new GetOverviewOperation(tags))
+                                    .join();
+            overviewInfo.setProjectVersion(version.getProjectVersion());
+            overviewInfo.setGitCommitAbbrev(version.getGitCommitAbbrev());
+        } else {
+
+            NodeEngineImpl nodeEngine = this.textCommandService.getNode().getNodeEngine();
+            overviewInfo = GetOverviewOperation.getOverviewInfo(seaTunnelServer, nodeEngine, tags);
+            overviewInfo.setProjectVersion(version.getProjectVersion());
+            overviewInfo.setGitCommitAbbrev(version.getGitCommitAbbrev());
+        }
+
+        this.prepareResponse(
+                command,
+                JsonUtil.toJsonObject(JsonUtils.toMap(JsonUtils.toJsonString(overviewInfo))));
+    }
+
     private void getSystemMonitoringInformation(HttpGetCommand command) {
         Cluster cluster = textCommandService.getNode().hazelcastInstance.getCluster();
         nodeEngine = textCommandService.getNode().hazelcastInstance.node.nodeEngine;
@@ -252,24 +305,20 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
         uri = StringUtil.stripTrailingSlash(uri);
         int indexEnd = uri.indexOf('/', URI_MAPS.length());
         String jobId = uri.substring(indexEnd + 1);
-
-        JobInfo jobInfo =
-                (JobInfo)
-                        this.textCommandService
-                                .getNode()
-                                .getNodeEngine()
-                                .getHazelcastInstance()
-                                .getMap(Constant.IMAP_RUNNING_JOB_INFO)
-                                .get(Long.valueOf(jobId));
-
-        JobState finishedJobState =
-                (JobState)
-                        this.textCommandService
-                                .getNode()
-                                .getNodeEngine()
-                                .getHazelcastInstance()
-                                .getMap(Constant.IMAP_FINISHED_JOB_STATE)
-                                .get(Long.valueOf(jobId));
+        IMap<Object, Object> jobInfoMap =
+                this.textCommandService
+                        .getNode()
+                        .getNodeEngine()
+                        .getHazelcastInstance()
+                        .getMap(Constant.IMAP_RUNNING_JOB_INFO);
+        JobInfo jobInfo = (JobInfo) jobInfoMap.get(Long.valueOf(jobId));
+        IMap<Object, Object> finishedJobStateMap =
+                this.textCommandService
+                        .getNode()
+                        .getNodeEngine()
+                        .getHazelcastInstance()
+                        .getMap(Constant.IMAP_FINISHED_JOB_STATE);
+        JobState finishedJobState = (JobState) finishedJobStateMap.get(Long.valueOf(jobId));
         if (!jobId.isEmpty() && jobInfo != null) {
             this.prepareResponse(command, convertToJson(jobInfo, Long.parseLong(jobId)));
         } else if (!jobId.isEmpty() && finishedJobState != null) {
@@ -318,12 +367,31 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
                         .collect(JsonArray::new, JsonArray::add, JsonArray::add));
     }
 
-    private Map<String, Long> getJobMetrics(String jobMetrics) {
-        Map<String, Long> metricsMap = new HashMap<>();
+    private Map<String, Object> getJobMetrics(String jobMetrics) {
+        Map<String, Object> metricsMap = new HashMap<>();
         long sourceReadCount = 0L;
         long sinkWriteCount = 0L;
+        Map<String, JsonNode> tableSourceReceivedCountMap = new HashMap<>();
+        Map<String, JsonNode> tableSinkWriteCountMap = new HashMap<>();
         try {
             JsonNode jobMetricsStr = new ObjectMapper().readTree(jobMetrics);
+            StreamSupport.stream(
+                            Spliterators.spliteratorUnknownSize(jobMetricsStr.fieldNames(), 0),
+                            false)
+                    .filter(metricName -> metricName.contains("#"))
+                    .forEach(
+                            metricName -> {
+                                String tableName =
+                                        TablePath.of(metricName.split("#")[1]).getFullName();
+                                if (metricName.startsWith(SOURCE_RECEIVED_COUNT)) {
+                                    tableSourceReceivedCountMap.put(
+                                            tableName, jobMetricsStr.get(metricName));
+                                }
+                                if (metricName.startsWith(SOURCE_RECEIVED_COUNT)) {
+                                    tableSinkWriteCountMap.put(
+                                            tableName, jobMetricsStr.get(metricName));
+                                }
+                            });
             JsonNode sourceReceivedCountJson = jobMetricsStr.get(SOURCE_RECEIVED_COUNT);
             JsonNode sinkWriteCountJson = jobMetricsStr.get(SINK_WRITE_COUNT);
             for (int i = 0; i < jobMetricsStr.get(SOURCE_RECEIVED_COUNT).size(); i++) {
@@ -335,9 +403,36 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
         } catch (JsonProcessingException | NullPointerException e) {
             return metricsMap;
         }
+
+        Map<String, Long> tableSourceReceivedCount =
+                tableSourceReceivedCountMap.entrySet().stream()
+                        .collect(
+                                Collectors.toMap(
+                                        Map.Entry::getKey,
+                                        entry ->
+                                                StreamSupport.stream(
+                                                                entry.getValue().spliterator(),
+                                                                false)
+                                                        .mapToLong(
+                                                                node -> node.get("value").asLong())
+                                                        .sum()));
+        Map<String, Long> tableSinkWriteCount =
+                tableSinkWriteCountMap.entrySet().stream()
+                        .collect(
+                                Collectors.toMap(
+                                        Map.Entry::getKey,
+                                        entry ->
+                                                StreamSupport.stream(
+                                                                entry.getValue().spliterator(),
+                                                                false)
+                                                        .mapToLong(
+                                                                node -> node.get("value").asLong())
+                                                        .sum()));
+
         metricsMap.put(SOURCE_RECEIVED_COUNT, sourceReadCount);
         metricsMap.put(SINK_WRITE_COUNT, sinkWriteCount);
-
+        metricsMap.put(TABLE_SOURCE_RECEIVED_COUNT, tableSourceReceivedCount);
+        metricsMap.put(TABLE_SINK_WRITE_COUNT, tableSinkWriteCount);
         return metricsMap;
     }
 
@@ -431,11 +526,24 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
                 .add(
                         RestConstant.IS_START_WITH_SAVE_POINT,
                         jobImmutableInformation.isStartWithSavePoint())
-                .add(RestConstant.METRICS, JsonUtil.toJsonObject(getJobMetrics(jobMetrics)));
+                .add(RestConstant.METRICS, toJsonObject(getJobMetrics(jobMetrics)));
 
         return jobInfoJson;
     }
 
+    private JsonObject toJsonObject(Map<String, Object> jobMetrics) {
+        JsonObject members = new JsonObject();
+        jobMetrics.forEach(
+                (key, value) -> {
+                    if (value instanceof Map) {
+                        members.add(key, toJsonObject((Map<String, Object>) value));
+                    } else {
+                        members.add(key, value.toString());
+                    }
+                });
+        return members;
+    }
+
     private JsonObject getJobInfoJson(JobState jobState, String jobMetrics, JobDAGInfo jobDAGInfo) {
         return new JsonObject()
                 .add(RestConstant.JOB_ID, String.valueOf(jobState.getJobId()))
@@ -454,6 +562,6 @@ public class RestHttpGetCommandProcessor extends HttpCommandProcessor<HttpGetCom
                                 DateTimeUtils.Formatter.YYYY_MM_DD_HH_MM_SS))
                 .add(RestConstant.JOB_DAG, JsonUtils.toJsonString(jobDAGInfo))
                 .add(RestConstant.PLUGIN_JARS_URLS, new JsonArray())
-                .add(RestConstant.METRICS, JsonUtil.toJsonObject(getJobMetrics(jobMetrics)));
+                .add(RestConstant.METRICS, toJsonObject(getJobMetrics(jobMetrics)));
     }
 }
