@@ -28,9 +28,15 @@ import org.apache.seatunnel.engine.core.job.PipelineStatus;
 import org.apache.seatunnel.engine.server.AbstractSeaTunnelServerTest;
 import org.apache.seatunnel.engine.server.TestUtils;
 import org.apache.seatunnel.engine.server.checkpoint.CheckpointCloseReason;
+import org.apache.seatunnel.engine.server.checkpoint.CheckpointCoordinator;
+import org.apache.seatunnel.engine.server.dag.physical.PhysicalVertex;
 import org.apache.seatunnel.engine.server.dag.physical.PipelineLocation;
+import org.apache.seatunnel.engine.server.dag.physical.SubPlan;
 import org.apache.seatunnel.engine.server.execution.TaskGroupLocation;
 import org.apache.seatunnel.engine.server.resourcemanager.resource.SlotProfile;
+import org.apache.seatunnel.engine.server.service.slot.SlotService;
+import org.apache.seatunnel.engine.server.task.CoordinatorTask;
+import org.apache.seatunnel.engine.server.task.SeaTunnelTask;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
@@ -219,7 +225,70 @@ public class JobMasterTest extends AbstractSeaTunnelServerTest {
         Assertions.assertTrue(jobMaster.isNeedRestore());
     }
 
+    @Test
+    public void testCloseIdleTask() throws InterruptedException {
+        long jobId = instance.getFlakeIdGenerator(Constant.SEATUNNEL_ID_GENERATOR_NAME).newId();
+        JobMaster jobMaster = newJobInstanceWithRunningState(jobId);
+        Assertions.assertEquals(JobStatus.RUNNING, jobMaster.getJobStatus());
+
+        assertCloseIdleTask(jobMaster);
+
+        server.getCoordinatorService().savePoint(jobId);
+        server.getCoordinatorService().getJobStatus(jobId);
+        await().atMost(60, TimeUnit.SECONDS)
+                .untilAsserted(
+                        () -> {
+                            JobStatus jobStatus =
+                                    server.getCoordinatorService().getJobStatus(jobId);
+                            Assertions.assertEquals(JobStatus.SAVEPOINT_DONE, jobStatus);
+                        });
+        jobMaster = newJobInstanceWithRunningState(jobId, true);
+        Assertions.assertEquals(JobStatus.RUNNING, jobMaster.getJobStatus());
+
+        assertCloseIdleTask(jobMaster);
+    }
+
+    private void assertCloseIdleTask(JobMaster jobMaster) {
+        SlotService slotService = server.getSlotService();
+        Assertions.assertEquals(4, slotService.getWorkerProfile().getAssignedSlots().length);
+
+        Assertions.assertEquals(1, jobMaster.getPhysicalPlan().getPipelineList().size());
+        SubPlan subPlan = jobMaster.getPhysicalPlan().getPipelineList().get(0);
+        try {
+            PhysicalVertex coordinatorVertex1 = subPlan.getCoordinatorVertexList().get(0);
+            CoordinatorTask coordinatorTask =
+                    (CoordinatorTask)
+                            coordinatorVertex1.getTaskGroup().getTasks().stream().findFirst().get();
+            jobMaster
+                    .getCheckpointManager()
+                    .readyToCloseIdleTask(coordinatorTask.getTaskLocation());
+            Assertions.fail("should throw UnsupportedOperationException");
+        } catch (UnsupportedOperationException e) {
+            // ignore
+        }
+
+        Assertions.assertEquals(2, subPlan.getPhysicalVertexList().size());
+        PhysicalVertex taskGroup1 = subPlan.getPhysicalVertexList().get(0);
+        SeaTunnelTask seaTunnelTask =
+                (SeaTunnelTask) taskGroup1.getTaskGroup().getTasks().stream().findFirst().get();
+        jobMaster.getCheckpointManager().readyToCloseIdleTask(seaTunnelTask.getTaskLocation());
+
+        CheckpointCoordinator checkpointCoordinator =
+                jobMaster
+                        .getCheckpointManager()
+                        .getCheckpointCoordinator(seaTunnelTask.getTaskLocation().getPipelineId());
+        await().atMost(60, TimeUnit.SECONDS)
+                .until(() -> checkpointCoordinator.getClosedIdleTask().size() == 3);
+        await().atMost(60, TimeUnit.SECONDS)
+                .until(() -> slotService.getWorkerProfile().getAssignedSlots().length == 3);
+    }
+
     private JobMaster newJobInstanceWithRunningState(long jobId) throws InterruptedException {
+        return newJobInstanceWithRunningState(jobId, false);
+    }
+
+    private JobMaster newJobInstanceWithRunningState(long jobId, boolean restore)
+            throws InterruptedException {
         LogicalDag testLogicalDag =
                 TestUtils.createTestLogicalPlan(
                         "stream_fakesource_to_file.conf", "test_clear_coordinator_service", jobId);
@@ -228,6 +297,7 @@ public class JobMasterTest extends AbstractSeaTunnelServerTest {
                 new JobImmutableInformation(
                         jobId,
                         "Test",
+                        restore,
                         nodeEngine.getSerializationService().toData(testLogicalDag),
                         testLogicalDag.getJobConfig(),
                         Collections.emptyList(),
@@ -236,7 +306,8 @@ public class JobMasterTest extends AbstractSeaTunnelServerTest {
         Data data = nodeEngine.getSerializationService().toData(jobImmutableInformation);
 
         PassiveCompletableFuture<Void> voidPassiveCompletableFuture =
-                server.getCoordinatorService().submitJob(jobId, data);
+                server.getCoordinatorService()
+                        .submitJob(jobId, data, jobImmutableInformation.isStartWithSavePoint());
         voidPassiveCompletableFuture.join();
 
         JobMaster jobMaster = server.getCoordinatorService().getJobMaster(jobId);
