@@ -24,6 +24,8 @@ import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ArrayNode;
 import org.apache.seatunnel.shade.com.fasterxml.jackson.databind.node.ObjectNode;
 
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.table.catalog.CatalogTableUtil;
 import org.apache.seatunnel.api.table.type.DecimalType;
 import org.apache.seatunnel.api.table.type.LocalTimeType;
 import org.apache.seatunnel.api.table.type.MapType;
@@ -35,8 +37,10 @@ import org.apache.seatunnel.common.exception.SeaTunnelRuntimeException;
 import org.apache.seatunnel.common.utils.JsonUtils;
 import org.apache.seatunnel.format.json.exception.SeaTunnelJsonFormatException;
 
+import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
+import java.io.IOException;
 import java.math.BigDecimal;
 import java.sql.Timestamp;
 import java.time.LocalDate;
@@ -166,9 +170,9 @@ public class JsonRowDataSerDeSchemaTest {
                                         new MapType(STRING_TYPE, new MapType(STRING_TYPE, INT_TYPE))
                                     })
                         });
-
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
         JsonDeserializationSchema deserializationSchema =
-                new JsonDeserializationSchema(false, false, schema);
+                new JsonDeserializationSchema(catalogTables, false, false);
 
         SeaTunnelRow expected = new SeaTunnelRow(13);
         expected.setField(0, true);
@@ -226,8 +230,10 @@ public class JsonRowDataSerDeSchemaTest {
                                     new SeaTunnelDataType[] {STRING_TYPE, INT_TYPE})
                         });
 
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
+
         JsonDeserializationSchema deserializationSchema =
-                new JsonDeserializationSchema(false, false, schema);
+                new JsonDeserializationSchema(catalogTables, false, false);
         JsonSerializationSchema serializationSchema = new JsonSerializationSchema(schema);
 
         ObjectMapper objectMapper = new ObjectMapper();
@@ -302,8 +308,11 @@ public class JsonRowDataSerDeSchemaTest {
                             new MapType(STRING_TYPE, DOUBLE_TYPE)
                         });
 
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", rowType);
+
         JsonDeserializationSchema deserializationSchema =
-                new JsonDeserializationSchema(false, true, rowType);
+                new JsonDeserializationSchema(catalogTables, false, true);
+
         JsonSerializationSchema serializationSchema = new JsonSerializationSchema(rowType);
 
         for (int i = 0; i < jsons.length; i++) {
@@ -318,8 +327,10 @@ public class JsonRowDataSerDeSchemaTest {
     public void testDeserializationNullRow() throws Exception {
         SeaTunnelRowType schema =
                 new SeaTunnelRowType(new String[] {"name"}, new SeaTunnelDataType[] {STRING_TYPE});
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
+
         JsonDeserializationSchema deserializationSchema =
-                new JsonDeserializationSchema(true, false, schema);
+                new JsonDeserializationSchema(catalogTables, true, false);
         String s = null;
         assertNull(deserializationSchema.deserialize(s));
     }
@@ -328,9 +339,10 @@ public class JsonRowDataSerDeSchemaTest {
     public void testDeserializationMissingNode() throws Exception {
         SeaTunnelRowType schema =
                 new SeaTunnelRowType(new String[] {"name"}, new SeaTunnelDataType[] {STRING_TYPE});
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
 
         JsonDeserializationSchema deserializationSchema =
-                new JsonDeserializationSchema(true, false, schema);
+                new JsonDeserializationSchema(catalogTables, true, false);
         SeaTunnelRow rowData = deserializationSchema.deserialize("".getBytes());
         assertEquals(null, rowData);
     }
@@ -347,8 +359,11 @@ public class JsonRowDataSerDeSchemaTest {
         SeaTunnelRowType schema =
                 new SeaTunnelRowType(new String[] {"name"}, new SeaTunnelDataType[] {STRING_TYPE});
 
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
+
         // pass on missing field
-        final JsonDeserializationSchema deser = new JsonDeserializationSchema(false, false, schema);
+        final JsonDeserializationSchema deser =
+                new JsonDeserializationSchema(catalogTables, false, false);
 
         SeaTunnelRow expected = new SeaTunnelRow(1);
         SeaTunnelRow actual = deser.deserialize(serializedJson);
@@ -367,8 +382,11 @@ public class JsonRowDataSerDeSchemaTest {
         SeaTunnelRowType schema =
                 new SeaTunnelRowType(new String[] {"name"}, new SeaTunnelDataType[] {STRING_TYPE});
 
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
+
         // fail on missing field
-        final JsonDeserializationSchema deser = new JsonDeserializationSchema(true, false, schema);
+        final JsonDeserializationSchema deser =
+                new JsonDeserializationSchema(catalogTables, true, false);
 
         SeaTunnelRuntimeException expected =
                 CommonError.jsonOperationError("Common", root.toString());
@@ -400,9 +418,11 @@ public class JsonRowDataSerDeSchemaTest {
         SeaTunnelRowType schema =
                 new SeaTunnelRowType(new String[] {"name"}, new SeaTunnelDataType[] {STRING_TYPE});
         SeaTunnelRow expected = new SeaTunnelRow(1);
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
 
         // ignore on parse error
-        final JsonDeserializationSchema deser = new JsonDeserializationSchema(false, true, schema);
+        final JsonDeserializationSchema deser =
+                new JsonDeserializationSchema(catalogTables, false, true);
         assertEquals(expected, deser.deserialize(serializedJson));
     }
 
@@ -415,7 +435,7 @@ public class JsonRowDataSerDeSchemaTest {
                 assertThrows(
                         SeaTunnelJsonFormatException.class,
                         () -> {
-                            new JsonDeserializationSchema(true, true, null);
+                            new JsonDeserializationSchema(null, true, true);
                         },
                         "expecting exception message: " + errorMessage);
         assertEquals(actual.getMessage(), errorMessage);
@@ -426,8 +446,11 @@ public class JsonRowDataSerDeSchemaTest {
         SeaTunnelRowType schema =
                 new SeaTunnelRowType(new String[] {"name"}, new SeaTunnelDataType[] {STRING_TYPE});
 
+        CatalogTable catalogTables = CatalogTableUtil.getCatalogTable("", "", "", "", schema);
+
         String noJson = "{]";
-        final JsonDeserializationSchema deser = new JsonDeserializationSchema(false, false, schema);
+        final JsonDeserializationSchema deser =
+                new JsonDeserializationSchema(catalogTables, false, false);
         SeaTunnelRuntimeException expected = CommonError.jsonOperationError("Common", noJson);
 
         SeaTunnelRuntimeException actual =
@@ -543,4 +566,116 @@ public class JsonRowDataSerDeSchemaTest {
         Map<?, ?> keyMap = (Map<?, ?>) converter.convert(keyMapNode, fieldName);
         assertEquals(expect, keyMap.keySet().iterator().next());
     }
+
+    @Test
+    public void testParseUnsupportedDateTimeFormat() throws IOException {
+        SeaTunnelRowType rowType =
+                new SeaTunnelRowType(
+                        new String[] {"date_field"},
+                        new SeaTunnelDataType<?>[] {LocalTimeType.LOCAL_DATE_TYPE});
+        JsonDeserializationSchema deserializationSchema =
+                new JsonDeserializationSchema(false, false, rowType);
+        String content = "{\"date_field\":\"2022-092-24\"}";
+        SeaTunnelRuntimeException exception =
+                Assertions.assertThrows(
+                        SeaTunnelRuntimeException.class,
+                        () -> deserializationSchema.deserialize(content.getBytes()));
+        Assertions.assertEquals(
+                "ErrorCode:[COMMON-32], ErrorDescription:[The date format '2022-092-24' of field 'date_field' is not supported. Please check the date format.]",
+                exception.getCause().getCause().getMessage());
+
+        SeaTunnelRowType rowType2 =
+                new SeaTunnelRowType(
+                        new String[] {"timestamp_field"},
+                        new SeaTunnelDataType<?>[] {
+                            LocalTimeType.LOCAL_DATE_TIME_TYPE,
+                        });
+        JsonDeserializationSchema deserializationSchema2 =
+                new JsonDeserializationSchema(false, false, rowType2);
+        String content2 = "{\"timestamp_field\": \"2022-09-24-22:45:00\"}";
+        SeaTunnelRuntimeException exception2 =
+                Assertions.assertThrows(
+                        SeaTunnelRuntimeException.class,
+                        () -> deserializationSchema2.deserialize(content2.getBytes()));
+        Assertions.assertEquals(
+                "ErrorCode:[COMMON-33], ErrorDescription:[The datetime format '2022-09-24-22:45:00' of field 'timestamp_field' is not supported. Please check the datetime format.]",
+                exception2.getCause().getCause().getMessage());
+    }
+
+    @Test
+    public void testSerializationWithNullValue() {
+        SeaTunnelRowType schema =
+                new SeaTunnelRowType(
+                        new String[] {
+                            "bool", "int", "longValue", "float", "name", "date", "time", "timestamp"
+                        },
+                        new SeaTunnelDataType[] {
+                            BOOLEAN_TYPE,
+                            INT_TYPE,
+                            LONG_TYPE,
+                            FLOAT_TYPE,
+                            STRING_TYPE,
+                            LocalTimeType.LOCAL_DATE_TYPE,
+                            LocalTimeType.LOCAL_TIME_TYPE,
+                            LocalTimeType.LOCAL_DATE_TIME_TYPE
+                        });
+
+        Object[] fields = new Object[] {null, null, null, null, null, null, null, null};
+        SeaTunnelRow expected = new SeaTunnelRow(fields);
+        assertEquals(
+                "{\"bool\":\"\\\\N\",\"int\":\"\\\\N\",\"longValue\":\"\\\\N\",\"float\":\"\\\\N\",\"name\":\"\\\\N\",\"date\":\"\\\\N\",\"time\":\"\\\\N\",\"timestamp\":\"\\\\N\"}",
+                new String(new JsonSerializationSchema(schema, "\\N").serialize(expected)));
+    }
+
+    @Test
+    public void testSerializationWithMapHasNonStringKey() {
+        SeaTunnelRowType schema =
+                new SeaTunnelRowType(
+                        new String[] {"mapii", "mapbb"},
+                        new SeaTunnelDataType[] {
+                            new MapType(INT_TYPE, INT_TYPE), new MapType(BOOLEAN_TYPE, INT_TYPE)
+                        });
+        Map<Integer, Integer> mapII = new HashMap<>();
+        mapII.put(1, 2);
+
+        Map<Boolean, Integer> mapBI = new HashMap<>();
+        mapBI.put(true, 3);
+
+        Object[] fields = new Object[] {mapII, mapBI};
+        SeaTunnelRow expected = new SeaTunnelRow(fields);
+        assertEquals(
+                "{\"mapii\":{\"1\":2},\"mapbb\":{\"true\":3}}",
+                new String(new JsonSerializationSchema(schema, "\\N").serialize(expected)));
+    }
+
+    @Test
+    public void testSerializationWithTimestamp() {
+        SeaTunnelRowType schema =
+                new SeaTunnelRowType(
+                        new String[] {"timestamp"},
+                        new SeaTunnelDataType[] {LocalTimeType.LOCAL_DATE_TIME_TYPE});
+        LocalDateTime timestamp = LocalDateTime.of(2022, 9, 24, 22, 45, 0, 123456000);
+        SeaTunnelRow row = new SeaTunnelRow(new Object[] {timestamp});
+        assertEquals(
+                "{\"timestamp\":\"2022-09-24T22:45:00.123456\"}",
+                new String(new JsonSerializationSchema(schema, "\\N").serialize(row)));
+
+        timestamp = LocalDateTime.of(2022, 9, 24, 22, 45, 0, 0);
+        row = new SeaTunnelRow(new Object[] {timestamp});
+        assertEquals(
+                "{\"timestamp\":\"2022-09-24T22:45:00\"}",
+                new String(new JsonSerializationSchema(schema, "\\N").serialize(row)));
+
+        timestamp = LocalDateTime.of(2022, 9, 24, 22, 45, 0, 1000);
+        row = new SeaTunnelRow(new Object[] {timestamp});
+        assertEquals(
+                "{\"timestamp\":\"2022-09-24T22:45:00.000001\"}",
+                new String(new JsonSerializationSchema(schema, "\\N").serialize(row)));
+
+        timestamp = LocalDateTime.of(2022, 9, 24, 22, 45, 0, 123456);
+        row = new SeaTunnelRow(new Object[] {timestamp});
+        assertEquals(
+                "{\"timestamp\":\"2022-09-24T22:45:00.000123456\"}",
+                new String(new JsonSerializationSchema(schema, "\\N").serialize(row)));
+    }
 }
