@@ -24,6 +24,9 @@ import org.apache.seatunnel.common.exception.CommonErrorCodeDeprecated;
 import org.apache.seatunnel.transform.exception.TransformException;
 import org.apache.seatunnel.transform.sql.SQLEngine;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import net.sf.jsqlparser.JSQLParserException;
 import net.sf.jsqlparser.expression.Expression;
 import net.sf.jsqlparser.parser.CCJSqlParserUtil;
@@ -46,6 +49,7 @@ import java.util.ServiceLoader;
 import java.util.stream.Collectors;
 
 public class ZetaSQLEngine implements SQLEngine {
+    private static final Logger log = LoggerFactory.getLogger(ZetaSQLEngine.class);
     private String inputTableName;
     @Nullable private String catalogTableName;
     private SeaTunnelRowType inputRowType;
@@ -119,8 +123,11 @@ public class ZetaSQLEngine implements SQLEngine {
                 String tableName = table.getName();
                 if (!inputTableName.equalsIgnoreCase(tableName)
                         && !tableName.equalsIgnoreCase(catalogTableName)) {
-                    throw new IllegalArgumentException(
-                            String.format("Table name: %s not found", tableName));
+                    log.warn(
+                            "SQL table name {} is not equal to input table name {} or catalog table name {}",
+                            tableName,
+                            inputTableName,
+                            catalogTableName);
                 }
             } else {
                 throw new IllegalArgumentException("Unsupported sub table syntax");
