@@ -58,6 +58,7 @@ public class ParallelMicroBatchPartitionReader extends ParallelBatchPartitionRea
     public ParallelMicroBatchPartitionReader(
             SeaTunnelSource<SeaTunnelRow, ?, ?> source,
             Integer parallelism,
+            String jobId,
             Integer subtaskId,
             Integer checkpointId,
             Integer checkpointInterval,
@@ -65,7 +66,7 @@ public class ParallelMicroBatchPartitionReader extends ParallelBatchPartitionRea
             String hdfsRoot,
             String hdfsUser,
             Map<String, String> envOptions) {
-        super(source, parallelism, subtaskId, envOptions);
+        super(source, parallelism, jobId, subtaskId, envOptions);
         this.checkpointId = checkpointId;
         this.checkpointInterval = checkpointInterval;
         this.checkpointPath = checkpointPath;
@@ -75,7 +76,7 @@ public class ParallelMicroBatchPartitionReader extends ParallelBatchPartitionRea
 
     @Override
     protected BaseSourceFunction<SeaTunnelRow> createInternalSource() {
-        return new InternalParallelSource<>(source, restoredState, parallelism, subtaskId);
+        return new InternalParallelSource<>(source, restoredState, parallelism, jobId, subtaskId);
     }
 
     @Override
