@@ -36,15 +36,18 @@ public class SeaTunnelScan implements Scan {
     private final SeaTunnelSource<SeaTunnelRow, ?, ?> source;
 
     private final int parallelism;
+    private final String jobId;
 
     private final CaseInsensitiveStringMap caseInsensitiveStringMap;
 
     public SeaTunnelScan(
             SeaTunnelSource<SeaTunnelRow, ?, ?> source,
             int parallelism,
+            String jobId,
             CaseInsensitiveStringMap caseInsensitiveStringMap) {
         this.source = source;
         this.parallelism = parallelism;
+        this.jobId = jobId;
         this.caseInsensitiveStringMap = caseInsensitiveStringMap;
     }
 
@@ -56,12 +59,12 @@ public class SeaTunnelScan implements Scan {
     @Override
     public Batch toBatch() {
         Map<String, String> envOptions = caseInsensitiveStringMap.asCaseSensitiveMap();
-        return new SeaTunnelBatch(source, parallelism, envOptions);
+        return new SeaTunnelBatch(source, parallelism, jobId, envOptions);
     }
 
     @Override
     public MicroBatchStream toMicroBatchStream(String checkpointLocation) {
         return new SeaTunnelMicroBatch(
-                source, parallelism, checkpointLocation, caseInsensitiveStringMap);
+                source, parallelism, jobId, checkpointLocation, caseInsensitiveStringMap);
     }
 }
